@@ -130,8 +130,8 @@ void SaveLensParameters(const wxString filename, HuginBase::Panorama* pano, unsi
     const char ** varname = HuginBase::Lens::variableNames;
     while (*varname)
     {
-        //ignore exposure value and hfov, hfov is separately handled by the code above
-        if (std::string(*varname) == "Eev" || std::string(*varname) == "v")
+        //ignore hfov, hfov is separately handled by the code above
+        if (std::string(*varname) == "v")
         {
             varname++;
             continue;
@@ -188,7 +188,7 @@ bool ApplyLensParameters(wxWindow * parent, HuginBase::Panorama *pano, HuginBase
             vars[i]=pano->getImageVariables(*it);
             for (HuginBase::LensVarMap::iterator it2 = lens.variables.begin(); it2 != lens.variables.end(); ++it2)
             {
-                if(it2->second.getName()=="EeV")
+                if (it2->second.getName() == "Eev" || it2->second.getName() == "Er" || it2->second.getName() == "Eb")
                 {
                     continue;
                 };
@@ -205,7 +205,7 @@ bool ApplyLensParameters(wxWindow * parent, HuginBase::Panorama *pano, HuginBase
         std::set<HuginBase::ImageVariableGroup::ImageVariableEnum> unlinkedVariables;
         for (HuginBase::LensVarMap::iterator it = lens.variables.begin(); it != lens.variables.end(); ++it)
         {
-            if(it->second.getName()=="EeV")
+            if(it->second.getName()=="Eev" || it->second.getName() == "Er" || it->second.getName() == "Eb")
             {
                 continue;
             };
@@ -321,11 +321,6 @@ bool LoadLensParametersChoose(wxWindow * parent, HuginBase::Lens & lens,
             // loop to load lens variables
             const char ** varname = HuginBase::Lens::variableNames;
             while (*varname) {
-                if (std::string(*varname) == "Eev")
-                {
-                    varname++;
-                    continue;
-                }
                 wxString key(wxT("Lens/"));
                 key.append(wxString(*varname, wxConvLocal));
                 d = 0;
@@ -470,5 +465,113 @@ bool CheckLensStacks(HuginBase::Panorama* pano, bool allowCancel)
             return false;
         };
     };
+}
+
+namespace FormatString
+{
+wxString GetExifDateTime(const HuginBase::SrcPanoImage* img)
+{
+    wxString s;
+    struct tm exifdatetime;
+    if (img->getExifDateTime(&exifdatetime) == 0)
+    {
+        wxDateTime s_datetime = wxDateTime(exifdatetime);
+        s = s_datetime.Format();
+    }
+    else
+    {
+        s = wxString(img->getExifDate().c_str(), wxConvLocal);
+    }
+    return s;
+}
+
+wxString GetFocalLength(const HuginBase::SrcPanoImage* img)
+{
+    wxString s;
+    if (img->getExifFocalLength() > 0.0)
+    {
+        if (img->getExifFocalLength35() > 0.0)
+        {
+            s = wxString::Format(wxT("%0.1f mm (%0.0f mm)"), img->getExifFocalLength(), img->getExifFocalLength35());
+        }
+        else
+        {
+            s = wxString::Format(wxT("%0.1f mm"), img->getExifFocalLength());
+        };
+    }
+    else
+    {
+        s = wxEmptyString;
+    };
+    return s;
 };
 
+wxString GetAperture(const HuginBase::SrcPanoImage* img)
+{
+    wxString s;
+    if (img->getExifAperture() > 0)
+    {
+        s = wxString::Format(wxT("F%.1f"), img->getExifAperture());
+    }
+    else
+    {
+        s = wxEmptyString;
+    };
+    return s;
+};
+
+wxString GetExposureTime(const HuginBase::SrcPanoImage* img)
+{
+    wxString s;
+    const double exposureTime = img->getExifExposureTime();
+    if (exposureTime > 0.5)
+    {
+        if (exposureTime >= 1.0)
+        {
+            if (exposureTime >= 10.0)
+            {
+                s = wxString::Format(wxT("%3.0f s"), exposureTime);
+            }
+            else
+            {
+                s = wxString::Format(wxT("%1.1f s"), exposureTime);
+            }
+        }
+        else
+        {
+            s = wxString::Format(wxT("%1.2f s"), exposureTime);
+        }
+    }
+    else
+    {
+        if (exposureTime > 1e-9)
+        {
+            s = wxString::Format(wxT("1/%0.0f s"), 1.0 / exposureTime);
+        }
+        else
+        {
+            //Sanity
+            s = wxEmptyString;
+        }
+    }
+    return s;
+};
+
+wxString GetIso(const HuginBase::SrcPanoImage* img)
+{
+    wxString s;
+    if (img->getExifISO() > 0)
+    {
+        s = wxString::Format(wxT("%0.0f"), img->getExifISO());
+    }
+    else
+    {
+        s = wxEmptyString;
+    };
+    return s;
+};
+
+};
+
+
+
