@@ -21,8 +21,8 @@
 *
 */
 
+#include "base_wx/platform.h"
 #include "StitchingExecutor.h"
-
 #include <list>
 #include <wx/config.h>
 #include <wx/translation.h>
@@ -34,7 +34,6 @@
 #include "hugin_base/panotools/PanoToolsUtils.h"
 #include "hugin_base/panodata/PanoramaOptions.h"
 #include "hugin_base/algorithms/basic/LayerStacks.h"
-#include "base_wx/platform.h"
 #include "base_wx/wxPlatform.h"
 #include "base_wx/LensTools.h"
 #include "hugin/config_defaults.h"
@@ -64,20 +63,6 @@ namespace HuginQueue
             };
         };
 
-        /** return the temp dir from the preferences, ensure that it ends with path separator */
-        const wxString GetConfigTempDir(const wxConfigBase* config)
-        {
-            wxString tempDir = config->Read(wxT("tempDir"), wxT(""));
-            if (!tempDir.IsEmpty())
-            {
-                if (tempDir.Last() != wxFileName::GetPathSeparator())
-                {
-                    tempDir.Append(wxFileName::GetPathSeparator());
-                }
-            };
-            return tempDir;
-        };
-
         /** generate the final argfile
             @return full name of generated argfile 
         */
@@ -390,13 +375,13 @@ namespace HuginQueue
         };
     } // namespace detail
 
-    CommandQueue* GetStitchingCommandQueue(const HuginBase::Panorama & pano, const wxString& ExePath, const wxString& project, const wxString& prefix, wxString& statusText, wxArrayString& outputFiles, wxArrayString& tempFilesDelete)
+    CommandQueue* GetStitchingCommandQueue(const HuginBase::Panorama & pano, const wxString& ExePath, const wxString& project, const wxString& prefix, wxString& statusText, wxArrayString& outputFiles, wxArrayString& tempFilesDelete, std::ostream& errStream)
     {
         CommandQueue* commands = new CommandQueue;
         const HuginBase::UIntSet allActiveImages = getImagesinROI(pano, pano.getActiveImages());
         if (allActiveImages.empty())
         {
-            std::cerr << "ERROR: No active images in ROI. Nothing to do." << std::endl;
+            errStream << "ERROR: No active images in ROI. Nothing to do." << std::endl;
             return commands;
         }
         std::vector<HuginBase::UIntSet> stacks;
@@ -407,17 +392,17 @@ namespace HuginQueue
         opts.remapUsingGPU = config->Read(wxT("/Nona/UseGPU"), HUGIN_NONA_USEGPU) == 1;
         if (opts.remapper != HuginBase::PanoramaOptions::NONA)
         {
-            std::cerr << "ERROR: Only nona remappper is supported by hugin_executor." << std::endl;
+            errStream << "ERROR: Only nona remappper is supported by hugin_executor." << std::endl;
             return commands;
         };
         if (opts.blendMode != HuginBase::PanoramaOptions::ENBLEND_BLEND && opts.blendMode != HuginBase::PanoramaOptions::INTERNAL_BLEND)
         {
-            std::cerr << "ERROR: Only enblend and internal remappper are currently supported by hugin_executor." << std::endl;
+            errStream << "ERROR: Only enblend and internal remappper are currently supported by hugin_executor." << std::endl;
             return commands;
         };
         if (opts.hdrMergeMode != HuginBase::PanoramaOptions::HDRMERGE_AVERAGE)
         {
-            std::cerr << "ERROR: Only hdr merger HDRMERGE_AVERAGE is currently supported by hugin_executor." << std::endl;
+            errStream << "ERROR: Only hdr merger HDRMERGE_AVERAGE is currently supported by hugin_executor." << std::endl;
             return commands;
         };
         double exiftoolVersion;
@@ -572,7 +557,7 @@ namespace HuginQueue
                         }
                         else
                         {
-                            std::cerr << "ERROR: Invalid output image type found." << std::endl;
+                            errStream << "ERROR: Invalid output image type found." << std::endl;
                             return commands;
                         };
                     };
@@ -837,6 +822,10 @@ namespace HuginQueue
                             break;
                     };
                     outputFiles.Add(mergedStacksFilename);
+                    if (copyMetadata)
+                    {
+                        filesForFullExiftool.Add(mergedStacksFilename);
+                    };
                 };
             };
             if (!opts.outputHDRLayers)
@@ -869,11 +858,11 @@ namespace HuginQueue
         // do some checks on the way
         // if an error occurs or the input is not valid, the queue is cleared and the function returns false
         bool AddBlenderCommand(CommandQueue* queue, const wxString& ExePath, const wxString& prog, 
-            const int& stepNr, const wxString& arguments, const wxString& description)
+            const int& stepNr, const wxString& arguments, const wxString& description, std::ostream& errStream)
         {
             if (prog.IsEmpty())
             {
-                std::cerr << "ERROR: Step " << stepNr << " has no program name specified." << std::endl;
+                errStream << "ERROR: Step " << stepNr << " has no program name specified." << std::endl;
                 CleanQueue(queue);
                 return false;
             }
@@ -975,19 +964,19 @@ namespace HuginQueue
 
     }
 
-    CommandQueue* GetStitchingCommandQueueUserOutput(const HuginBase::Panorama & pano, const wxString& ExePath, const wxString& project, const wxString& prefix, const wxString& outputSettings, wxString& statusText, wxArrayString& outputFiles, wxArrayString& tempFilesDelete)
+    CommandQueue* GetStitchingCommandQueueUserOutput(const HuginBase::Panorama & pano, const wxString& ExePath, const wxString& project, const wxString& prefix, const wxString& outputSettings, wxString& statusText, wxArrayString& outputFiles, wxArrayString& tempFilesDelete, std::ostream& errStream)
     {
         CommandQueue* commands = new CommandQueue;
         const HuginBase::UIntSet allActiveImages = getImagesinROI(pano, pano.getActiveImages());
         if (allActiveImages.empty())
         {
-            std::cerr << "ERROR: No active images in ROI. Nothing to do." << std::endl;
+            errStream << "ERROR: No active images in ROI. Nothing to do." << std::endl;
             return commands;
         }
         wxFileInputStream input(outputSettings);
         if (!input.IsOk())
         {
-            std::cerr << "ERROR: Can not open file \"" << outputSettings.mb_str(wxConvLocal) << "\"." << std::endl;
+            errStream << "ERROR: Can not open file \"" << outputSettings.mb_str(wxConvLocal) << "\"." << std::endl;
             return commands;
         }
         wxFileConfig settings(input);
@@ -995,10 +984,10 @@ namespace HuginQueue
         settings.Read(wxT("/General/StepCount"), &stepCount, 0);
         if (stepCount == 0)
         {
-            std::cerr << "ERROR: User-setting does not define any output steps." << std::endl;
+            errStream << "ERROR: User-setting does not define any output steps." << std::endl;
             return commands;
         }
-        const wxString desc = GetSettingString(&settings, wxT("/General/Description"), wxEmptyString);
+        const wxString desc = GetSettingStringTranslated(&settings, wxT("/General/Description"), wxEmptyString);
         if (desc.IsEmpty())
         {
             statusText = wxString::Format(_("Stitching using \"%s\""), outputSettings.c_str());
@@ -1046,7 +1035,7 @@ namespace HuginQueue
             stepString << i;
             if (!settings.HasGroup(stepString))
             {
-                std::cerr << "ERROR: Output specifies " << stepCount << " steps, but step " << i << " is missing in configuration." << std::endl;
+                errStream << "ERROR: Output specifies " << stepCount << " steps, but step " << i << " is missing in configuration." << std::endl;
                 CleanQueue(commands);
                 return commands;
             }
@@ -1054,18 +1043,18 @@ namespace HuginQueue
             const wxString stepType=GetSettingString(&settings, wxT("Type"));
             if (stepType.IsEmpty())
             {
-                std::cerr << "ERROR: \"" << stepString.mb_str(wxConvLocal) << "\" has no type defined." << std::endl;
+                errStream << "ERROR: \"" << stepString.mb_str(wxConvLocal) << "\" has no type defined." << std::endl;
                 CleanQueue(commands);
                 return commands;
             };
             wxString args = GetSettingString(&settings, wxT("Arguments"));
             if (args.IsEmpty())
             {
-                std::cerr << "ERROR: Step " << i << " has no arguments given." << std::endl;
+                errStream << "ERROR: Step " << i << " has no arguments given." << std::endl;
                 CleanQueue(commands);
                 return commands;
             }
-            const wxString description = GetSettingString(&settings, wxT("Description"));
+            const wxString description = GetSettingStringTranslated(&settings, wxT("Description"));
             if (stepType.CmpNoCase(wxT("remap")) == 0)
             {
                 // build nona command
@@ -1123,14 +1112,14 @@ namespace HuginQueue
                     wxString resultFile = GetSettingString(&settings, wxT("Result"));
                     if (resultFile.IsEmpty())
                     {
-                        std::cerr << "ERROR: Step " << i << " has no result file specified." << std::endl;
+                        errStream << "ERROR: Step " << i << " has no result file specified." << std::endl;
                         CleanQueue(commands);
                         return commands;
                     };
                     resultFile.Replace(wxT("%prefix%"), prefix, true);
                     if (args.Replace(wxT("%result%"), wxEscapeFilename(resultFile), true) == 0)
                     {
-                        std::cerr << "ERROR: Step " << i << " has missing %result% placeholder in arguments." << std::endl;
+                        errStream << "ERROR: Step " << i << " has missing %result% placeholder in arguments." << std::endl;
                         CleanQueue(commands);
                         return commands;
                     };
@@ -1140,7 +1129,7 @@ namespace HuginQueue
                     {
                         if (args.Replace(wxT("%input%"), GetQuotedFilenamesString(remappedImages), true) == 0)
                         {
-                            std::cerr << "ERROR: Step " << i << " has missing %input% placeholder in arguments." << std::endl;
+                            errStream << "ERROR: Step " << i << " has missing %input% placeholder in arguments." << std::endl;
                             CleanQueue(commands);
                             return commands;
                         };
@@ -1158,7 +1147,7 @@ namespace HuginQueue
                             };
                             if (args.Replace(wxT("%input%"), GetQuotedFilenamesString(stacksFiles), true) == 0)
                             {
-                                std::cerr << "ERROR: Step " << i << " has missing %input% placeholder in arguments." << std::endl;
+                                errStream << "ERROR: Step " << i << " has missing %input% placeholder in arguments." << std::endl;
                                 CleanQueue(commands);
                                 return commands;
                             };
@@ -1176,14 +1165,14 @@ namespace HuginQueue
                                 };
                                 if (args.Replace(wxT("%input%"), GetQuotedFilenamesString(exposureLayersFiles), true) == 0)
                                 {
-                                    std::cerr << "ERROR: Step " << i << " has missing %input% placeholder in arguments." << std::endl;
+                                    errStream << "ERROR: Step " << i << " has missing %input% placeholder in arguments." << std::endl;
                                     CleanQueue(commands);
                                     return commands;
                                 };
                             }
                             else
                             {
-                                std::cerr << "ERROR: Step " << i << " has invalid input type: \"" << BlenderInput.mb_str(wxConvLocal) << "\"." << std::endl;
+                                errStream << "ERROR: Step " << i << " has invalid input type: \"" << BlenderInput.mb_str(wxConvLocal) << "\"." << std::endl;
                                 CleanQueue(commands);
                                 return commands;
                             };
@@ -1196,7 +1185,7 @@ namespace HuginQueue
                         args.Prepend(wrapSwitch + wxT(" "));
                     }
                     if (!detail::AddBlenderCommand(commands, ExePath, GetSettingString(&settings, wxT("Program")), i,
-                        args, description))
+                        args, description, errStream))
                     {
                         return commands;
                     };
@@ -1227,18 +1216,18 @@ namespace HuginQueue
                             wxArrayString remappedStackImages = detail::GetNumberedFilename(prefix, intermediateImageType, stacks[stackNr]);
                             if (finalArgs.Replace(wxT("%input%"), GetQuotedFilenamesString(remappedStackImages), true) == 0)
                             {
-                                std::cerr << "ERROR: Step " << i << " has missing %input% placeholder in arguments." << std::endl;
+                                errStream << "ERROR: Step " << i << " has missing %input% placeholder in arguments." << std::endl;
                                 CleanQueue(commands);
                                 return commands;
                             };
                             if (finalArgs.Replace(wxT("%output%"), wxEscapeFilename(stacksFiles[stackNr]), true) == 0)
                             {
-                                std::cerr << "ERROR: Step " << i << " has missing %output% placeholder in arguments." << std::endl;
+                                errStream << "ERROR: Step " << i << " has missing %output% placeholder in arguments." << std::endl;
                                 CleanQueue(commands);
                                 return commands;
                             };
                             if (!detail::AddBlenderCommand(commands, ExePath, GetSettingString(&settings, wxT("Program")), i,
-                                finalArgs, description))
+                                finalArgs, description, errStream))
                             {
                                 return commands;
                             };
@@ -1270,18 +1259,18 @@ namespace HuginQueue
                                 wxArrayString remappedLayerImages = detail::GetNumberedFilename(prefix, intermediateImageType, exposureLayers[exposureLayerNr]);
                                 if (finalArgs.Replace(wxT("%input%"), GetQuotedFilenamesString(remappedLayerImages), true) == 0)
                                 {
-                                    std::cerr << "ERROR: Step " << i << " has missing %input% placeholder in arguments." << std::endl;
+                                    errStream << "ERROR: Step " << i << " has missing %input% placeholder in arguments." << std::endl;
                                     CleanQueue(commands);
                                     return commands;
                                 };
                                 if (finalArgs.Replace(wxT("%output%"), wxEscapeFilename(exposureLayersFiles[exposureLayerNr]), true) == 0)
                                 {
-                                    std::cerr << "ERROR: Step " << i << " has missing %output% placeholder in arguments." << std::endl;
+                                    errStream << "ERROR: Step " << i << " has missing %output% placeholder in arguments." << std::endl;
                                     CleanQueue(commands);
                                     return commands;
                                 };
                                 if (!detail::AddBlenderCommand(commands, ExePath, GetSettingString(&settings, wxT("Program")), i,
-                                    finalArgs, description))
+                                    finalArgs, description, errStream))
                                 {
                                     return commands;
                                 };
@@ -1300,39 +1289,39 @@ namespace HuginQueue
                                 wxString inputFiles = GetSettingString(&settings, wxT("File"));
                                 if (inputFiles.IsEmpty())
                                 {
-                                    std::cerr << "ERROR: Step " << i << " has no input/output file specified." << std::endl;
+                                    errStream << "ERROR: Step " << i << " has no input/output file specified." << std::endl;
                                     CleanQueue(commands);
                                     return commands;
                                 };
                                 if (args.Find(wxT("%file%")) == wxNOT_FOUND)
                                 {
-                                    std::cerr << "ERROR: Step " << i << " has missing %file% placeholder in arguments." << std::endl;
+                                    errStream << "ERROR: Step " << i << " has missing %file% placeholder in arguments." << std::endl;
                                     CleanQueue(commands);
                                     return commands;
                                 };
                                 args.Replace(wxT("%project%"), wxEscapeFilename(project), true);
                                 if (!detail::ReplacePrefixPlaceholder(args, prefix))
                                 {
-                                    std::cerr << "ERROR: Step " << i << " has invalid %prefix% placeholder in arguments." << std::endl;
+                                    errStream << "ERROR: Step " << i << " has invalid %prefix% placeholder in arguments." << std::endl;
                                     CleanQueue(commands);
                                     return commands;
                                 };
                                 if (!detail::ReplaceWidthHeightPlaceHolder(args, "width", opts.getWidth()))
                                 {
-                                    std::cerr << "ERROR: Step " << i << " has invalid %width% placeholder in arguments." << std::endl;
+                                    errStream << "ERROR: Step " << i << " has invalid %width% placeholder in arguments." << std::endl;
                                     CleanQueue(commands);
                                     return commands;
                                 }
                                 if (!detail::ReplaceWidthHeightPlaceHolder(args, "height", opts.getHeight()))
                                 {
-                                    std::cerr << "ERROR: Step " << i << " has invalid %height% placeholder in arguments." << std::endl;
+                                    errStream << "ERROR: Step " << i << " has invalid %height% placeholder in arguments." << std::endl;
                                     CleanQueue(commands);
                                     return commands;
                                 }
                                 const wxString progName = GetSettingString(&settings, wxT("Program"));
                                 if (progName.IsEmpty())
                                 {
-                                    std::cerr << "ERROR: Step " << i << " has no program name specified." << std::endl;
+                                    errStream << "ERROR: Step " << i << " has no program name specified." << std::endl;
                                     CleanQueue(commands);
                                     return commands;
                                 };
@@ -1361,7 +1350,7 @@ namespace HuginQueue
                                     {
                                         if (stacks.empty())
                                         {
-                                            std::cerr << "ERROR: Step " << i << " requests to modify stacks, but no stack was created before." << std::endl;
+                                            errStream << "ERROR: Step " << i << " requests to modify stacks, but no stack was created before." << std::endl;
                                             CleanQueue(commands);
                                             return commands;
                                         };
@@ -1378,7 +1367,7 @@ namespace HuginQueue
                                         {
                                             if (exposureLayers.empty())
                                             {
-                                                std::cerr << "ERROR: Step " << i << " requests to modify exposure layers, but no exposure layer was created before." << std::endl;
+                                                errStream << "ERROR: Step " << i << " requests to modify exposure layers, but no exposure layer was created before." << std::endl;
                                                 CleanQueue(commands);
                                                 return commands;
                                             };
@@ -1405,14 +1394,14 @@ namespace HuginQueue
                                     wxString resultFile = GetSettingString(&settings, wxT("Result"));
                                     if (resultFile.IsEmpty())
                                     {
-                                        std::cerr << "ERROR: Step " << i << " has no result file specified." << std::endl;
+                                        errStream << "ERROR: Step " << i << " has no result file specified." << std::endl;
                                         CleanQueue(commands);
                                         return commands;
                                     };
                                     resultFile.Replace(wxT("%prefix%"), prefix, true);
                                     if (args.Replace(wxT("%result%"), wxEscapeFilename(resultFile), true) == 0)
                                     {
-                                        std::cerr << "ERROR: Step " << i << " has missing %result% placeholder in arguments." << std::endl;
+                                        errStream << "ERROR: Step " << i << " has missing %result% placeholder in arguments." << std::endl;
                                         CleanQueue(commands);
                                         return commands;
                                     };
@@ -1422,7 +1411,7 @@ namespace HuginQueue
                                 }
                                 else
                                 {
-                                    std::cerr << "ERROR: Step " << i << " has unknown Type \"" << stepType.mb_str(wxConvLocal) << "\"." << std::endl;
+                                    errStream << "ERROR: Step " << i << " has unknown Type \"" << stepType.mb_str(wxConvLocal) << "\"." << std::endl;
                                     CleanQueue(commands);
                                     return commands;
                                 };
