@@ -137,6 +137,7 @@ bool wxAddCtrlPointGridCmd::processPanorama(HuginBase::Panorama& pano)
             }
         }
     }
+    HuginBase::PTools::calcCtrlPointErrors(pano);
     return true;
 }
 
@@ -870,10 +871,16 @@ bool wxApplyTemplateCmd::processPanorama(HuginBase::Panorama& pano)
         // keep old control points.
         newPano.setCtrlPoints(pano.getCtrlPoints());
         newPanoMem = newPano.getMemento();
+        // remmember setting of image type and icc profile
+        const int bands = pano.getNrOfBands();
+        const std::string iccProfile = pano.getICCProfileDesc();
         pano.setMemento(newPanoMem);
+        pano.setNrOfBands(bands);
+        pano.setICCProfileDesc(iccProfile);
     } else {
         wxMessageBox(_("Error loading project file"), _("Could not apply template"), wxICON_ERROR);
     }
+    HuginBase::PTools::calcCtrlPointErrors(pano);
     return true;
 }
 
@@ -896,7 +903,7 @@ bool PythonScriptPanoCmd::processPanorama(HuginBase::Panorama& pano)
             pano.imageChanged(i);
         };
     };
-
+    HuginBase::PTools::calcCtrlPointErrors(pano);
     return true;
 }
 #endif
