@@ -24,12 +24,10 @@
  *
  */
 
-#include <config.h>
+#include "hugin_config.h"
 
 // often necessary before panoinc.h
-#ifdef __APPLE__
 #include "panoinc_WX.h"
-#endif
 // standard hugin include
 #include "panoinc.h"
 // both includes above need to come before other wx includes on OSX
@@ -71,6 +69,7 @@ BEGIN_EVENT_TABLE(CPEditorPanel, wxPanel)
     EVT_LIST_ITEM_SELECTED(XRCID("cp_editor_cp_list"), CPEditorPanel::OnCPListSelect)
     EVT_LIST_ITEM_DESELECTED(XRCID("cp_editor_cp_list"), CPEditorPanel::OnCPListDeselect)
     EVT_LIST_COL_END_DRAG(XRCID("cp_editor_cp_list"), CPEditorPanel::OnColumnWidthChange)
+    EVT_LIST_COL_CLICK(XRCID("cp_editor_cp_list"), CPEditorPanel::OnColumnHeaderClick)
     EVT_CHOICE(XRCID("cp_editor_choice_zoom"), CPEditorPanel::OnZoom)
     EVT_TEXT_ENTER(XRCID("cp_editor_x1"), CPEditorPanel::OnTextPointChange )
     EVT_TEXT_ENTER(XRCID("cp_editor_y1"), CPEditorPanel::OnTextPointChange )
@@ -96,6 +95,15 @@ CPEditorPanel::CPEditorPanel()
     m_countCP = 0;
 }
 
+// helper function to set image in header
+void SetColumnImage(wxListCtrl* list, int col, int image)
+{
+    wxListItem item;
+    item.SetMask(wxLIST_MASK_IMAGE);
+    item.SetImage(image);
+    list->SetColumn(col, item);
+};
+
 bool CPEditorPanel::Create(wxWindow* parent, wxWindowID id,
                     const wxPoint& pos,
                     const wxSize& size,
@@ -156,6 +164,42 @@ bool CPEditorPanel::Create(wxWindow* parent, wxWindowID id,
         if(width != -1)
             m_cpList->SetColumnWidth(j, width);
     }
+    m_sortCol = config->Read(wxT("/CPEditorPanel/SortColumn"), -1);
+    m_sortAscending = config->Read(wxT("/CPEditorPanel/SortAscending"), 1) == 1 ? true : false;
+    if (m_sortCol != -1)
+    {
+        SetColumnImage(m_cpList, m_sortCol, m_sortAscending ? 0 : 1);
+    };
+
+    // creating bitmaps for indicating sorting order
+    wxMemoryDC memDC;
+    memDC.SetFont(GetFont());
+    wxSize fontSize = memDC.GetTextExtent(wxT("\u25b3"));
+    wxCoord charSize = std::max(fontSize.GetWidth(), fontSize.GetHeight());
+    wxImageList* sortIcons = new wxImageList(charSize, charSize, true, 0);
+    {
+        wxBitmap bmp(charSize, charSize);
+        wxMemoryDC dc(bmp);
+        dc.SetBackgroundMode(wxPENSTYLE_TRANSPARENT);
+        dc.SetBackground(GetBackgroundColour());
+        dc.Clear();
+        dc.SetFont(GetFont());
+        dc.DrawText(wxT("\u25b3"), (charSize - fontSize.GetWidth()) / 2, (charSize - fontSize.GetHeight()) / 2);
+        dc.SelectObject(wxNullBitmap);
+        sortIcons->Add(bmp, GetBackgroundColour());
+    };
+    {
+        wxBitmap bmp(charSize, charSize);
+        wxMemoryDC dc(bmp);
+        dc.SetBackgroundMode(wxPENSTYLE_TRANSPARENT);
+        dc.SetBackground(GetBackgroundColour());
+        dc.Clear();
+        dc.SetFont(GetFont());
+        dc.DrawText(wxT("\u25bd"), (charSize - fontSize.GetWidth()) / 2, (charSize - fontSize.GetHeight()) / 2);
+        dc.SelectObject(wxNullBitmap);
+        sortIcons->Add(bmp, GetBackgroundColour());
+    };
+    m_cpList->AssignImageList(sortIcons, wxIMAGE_LIST_SMALL);
 
     // other controls
     m_x1Text = XRCCTRL(*this,"cp_editor_x1", wxTextCtrl);
@@ -258,9 +302,13 @@ CPEditorPanel::~CPEditorPanel()
     m_x2Text->PopEventHandler(true);
     m_y2Text->PopEventHandler(true);
 
-    wxConfigBase::Get()->Write(wxT("/CPEditorPanel/autoAdd"), m_autoAddCB->IsChecked() ? 1 : 0);
-    wxConfigBase::Get()->Write(wxT("/CPEditorPanel/autoFineTune"), m_fineTuneCB->IsChecked() ? 1 : 0);
-    wxConfigBase::Get()->Write(wxT("/CPEditorPanel/autoEstimate"), m_estimateCB->IsChecked() ? 1 : 0);
+    wxConfigBase* config = wxConfig::Get();
+    config->Write(wxT("/CPEditorPanel/autoAdd"), m_autoAddCB->IsChecked() ? 1 : 0);
+    config->Write(wxT("/CPEditorPanel/autoFineTune"), m_fineTuneCB->IsChecked() ? 1 : 0);
+    config->Write(wxT("/CPEditorPanel/autoEstimate"), m_estimateCB->IsChecked() ? 1 : 0);
+    config->Write(wxT("/CPEditorPanel/SortColumn"), m_sortCol);
+    config->Write(wxT("/CPEditorPanel/SortAscending"), m_sortAscending ? 1 : 0);
+    config->Flush();
 
     m_pano->removeObserver(this);
     DEBUG_TRACE("dtor end");
@@ -346,7 +394,144 @@ void CPEditorPanel::UpdateTransforms()
         m_rightTransform.createTransform(m_pano->getImage(m_rightImageNr), m_pano->getOptions());
         m_rightInvTransform.createInvTransform(m_pano->getImage(m_rightImageNr), m_pano->getOptions());
     };
-};
+}
+
+// define sorting callbacks
+int wxCALLBACK SortIndexDescending(wxIntPtr item1, wxIntPtr item2, wxIntPtr WXUNUSED(sortData))
+{
+    if (item1 < item2)
+        return 1;
+    if (item1 > item2)
+        return -1;
+    return 0;
+}
+
+int wxCALLBACK SortIndexAscending(wxIntPtr item1, wxIntPtr item2, wxIntPtr WXUNUSED(sortData))
+{
+    if (item1 > item2)
+        return 1;
+    if (item1 < item2)
+        return -1;
+    return 0;
+}
+
+#define SORTASCENDING(functionName, var) \
+int wxCALLBACK functionName(wxIntPtr item1, wxIntPtr item2, wxIntPtr sortData)\
+{\
+    HuginBase::CPointVector* data = (HuginBase::CPointVector*)(sortData);\
+    if (data->at(item1).second.var > data->at(item2).second.var)\
+        return 1;\
+    if (data->at(item1).second.var < data->at(item2).second.var)\
+        return -1;\
+    return 0;\
+}
+
+#define SORTDESCENDING(functionName, var) \
+int wxCALLBACK functionName(wxIntPtr item1, wxIntPtr item2, wxIntPtr sortData)\
+{\
+    HuginBase::CPointVector* data = (HuginBase::CPointVector*)(sortData); \
+    if (data->at(item1).second.var < data->at(item2).second.var)\
+        return 1; \
+    if (data->at(item1).second.var > data->at(item2).second.var)\
+        return -1; \
+    return 0; \
+}
+
+SORTASCENDING(SortX1Ascending, x1)
+SORTDESCENDING(SortX1Descending, x1)
+SORTASCENDING(SortY1Ascending, y1)
+SORTDESCENDING(SortY1Descending, y1)
+SORTASCENDING(SortX2Ascending, x2)
+SORTDESCENDING(SortX2Descending, x2)
+SORTASCENDING(SortY2Ascending, y2)
+SORTDESCENDING(SortY2Descending, y2)
+SORTASCENDING(SortModeAscending, mode)
+SORTDESCENDING(SortModeDescending, mode)
+SORTASCENDING(SortErrorAscending, error)
+SORTDESCENDING(SortErrorDescending, error)
+
+#undef SORTASCENDING
+#undef SORTDESCENDING
+
+void CPEditorPanel::SortList()
+{
+    if (m_sortCol > -1)
+    {
+        switch (m_sortCol)
+        {
+            case 0:  // index
+                if (m_sortAscending)
+                {
+                    m_cpList->SortItems(SortIndexAscending, 0);
+                }
+                else
+                {
+                    m_cpList->SortItems(SortIndexDescending, 0);
+                };
+                break;
+            case 1: // x1
+                if (m_sortAscending)
+                {
+                    m_cpList->SortItems(SortX1Ascending, wxIntPtr(&currentPoints));
+                }
+                else
+                {
+                    m_cpList->SortItems(SortX1Descending, wxIntPtr(&currentPoints));
+                };
+                break;
+            case 2: // y1
+                if (m_sortAscending)
+                {
+                    m_cpList->SortItems(SortY1Ascending, wxIntPtr(&currentPoints));
+                }
+                else
+                {
+                    m_cpList->SortItems(SortY1Descending, wxIntPtr(&currentPoints));
+                };
+                break;
+            case 3: // x2
+                if (m_sortAscending)
+                {
+                    m_cpList->SortItems(SortX2Ascending, wxIntPtr(&currentPoints));
+                }
+                else
+                {
+                    m_cpList->SortItems(SortX2Descending, wxIntPtr(&currentPoints));
+                };
+                break;
+            case 4: // y2
+                if (m_sortAscending)
+                {
+                    m_cpList->SortItems(SortY2Ascending, wxIntPtr(&currentPoints));
+                }
+                else
+                {
+                    m_cpList->SortItems(SortY2Descending, wxIntPtr(&currentPoints));
+                };
+                break;
+            case 5: // mode
+                if (m_sortAscending)
+                {
+                    m_cpList->SortItems(SortModeAscending, wxIntPtr(&currentPoints));
+                }
+                else
+                {
+                    m_cpList->SortItems(SortModeDescending, wxIntPtr(&currentPoints));
+                };
+                break;
+            case 6: // error
+                if (m_sortAscending)
+                {
+                    m_cpList->SortItems(SortErrorAscending, wxIntPtr(&currentPoints));
+                }
+                else
+                {
+                    m_cpList->SortItems(SortErrorDescending, wxIntPtr(&currentPoints));
+                };
+                break;
+        };
+    };
+}
 
 void CPEditorPanel::OnCPEvent( CPEvent&  ev)
 {
@@ -440,6 +625,14 @@ void CPEditorPanel::OnCPEvent( CPEvent&  ev)
             }
             break;
         }
+    case CPEvent::CANCELED:
+        {
+            if (cpCreationState != NO_POINT)
+            {
+                changeState(NO_POINT);
+            };
+            break;
+        };
     case CPEvent::SCROLLED:
         {
             wxPoint d(hugin_utils::roundi(point.x), hugin_utils::roundi(point.y));
@@ -479,7 +672,7 @@ void CPEditorPanel::OnCPEvent( CPEvent&  ev)
                 };
             };
             changeState(NO_POINT);
-            if(cpToRemove.size()>0)
+            if(!cpToRemove.empty())
             {
                 PanoCommand::GlobalCmdHist::getInstance().addCommand(new PanoCommand::RemoveCtrlPointsCmd(*m_pano, cpToRemove));
             };
@@ -574,7 +767,11 @@ void CPEditorPanel::ClearSelection()
         // no point selected, no need to select one.
         return;
     }
-    m_cpList->SetItemState(m_selectedPoint, 0, wxLIST_STATE_SELECTED);
+    const long selectedPoint = m_cpList->FindItem(-1, m_selectedPoint);
+    if (selectedPoint != wxNOT_FOUND)
+    {
+        m_cpList->SetItemState(selectedPoint, 0, wxLIST_STATE_SELECTED);
+    };
 
     m_selectedPoint=UINT_MAX;
     changeState(NO_POINT);
@@ -603,8 +800,9 @@ void CPEditorPanel::SelectLocalPoint(unsigned int LVpointNr)
     m_cpModeChoice->SetSelection(p.mode);
     m_leftImg->selectPoint(LVpointNr);
     m_rightImg->selectPoint(LVpointNr);
-    m_cpList->SetItemState(LVpointNr, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
-    m_cpList->EnsureVisible(LVpointNr);
+    const long selectedPoint = m_cpList->FindItem(-1, LVpointNr);
+    m_cpList->SetItemState(selectedPoint, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
+    m_cpList->EnsureVisible(selectedPoint);
 
     EnablePointEdit(true);
 }
@@ -703,7 +901,7 @@ void CPEditorPanel::estimateAndAddOtherPoint(const hugin_utils::FDiff2D & p,
                     thisImg->setNewPoint(corrPoint.corrPos);
                     changeState(BOTH_POINTS_SELECTED);
                     wxString s1;
-                    s1.Printf(_("Point fine-tuned, angle: %.0f deg, correlation coefficient: %0.3f, curvature: %0.3f %0.3f "),
+                    s1.Printf(_("Point fine-tuned, angle: %.0f deg, correlation coefficient: %0.3f, curvature: %0.3f %0.3f"),
                               corrPoint.maxAngle, corrPoint.maxi, corrPoint.curv.x, corrPoint.curv.y );
                     
                     wxString s2 = s1 + wxT(" -- ") + wxString(_("change points, or press right mouse button to add the pair"));
@@ -834,9 +1032,9 @@ void CPEditorPanel::NewPointChange(hugin_utils::FDiff2D p, bool left)
                     if (corrRes.corrPos.x >= 0 && corrRes.corrPos.y >= 0 && corrRes.maxpos.x >= 0 && corrRes.maxpos.y >= 0)
                     {
                         thisImg->setScale(m_detailZoomFactor);
-                        thisImg->setNewPoint(corrRes.maxpos);
+                        thisImg->setNewPoint(corrRes.maxi > -1 ? corrRes.maxpos : p);
                         thisImg->update();
-                        otherImg->setNewPoint(corrRes.corrPos);
+                        otherImg->setNewPoint(corrRes.maxi > -1 ? corrRes.corrPos : newPoint);
                         changeState(BOTH_POINTS_SELECTED);
                     };
                 } else {
@@ -848,7 +1046,7 @@ void CPEditorPanel::NewPointChange(hugin_utils::FDiff2D p, bool left)
                     thisImg->setNewPoint(corrRes.maxpos);
                     otherImg->setNewPoint(corrRes.corrPos);
                     wxString s1;
-                    s1.Printf(_("Point fine-tuned, angle: %.0f deg, correlation coefficient: %0.3f, curvature: %0.3f %0.3f "),
+                    s1.Printf(_("Point fine-tuned, angle: %.0f deg, correlation coefficient: %0.3f, curvature: %0.3f %0.3f"),
                               corrRes.maxAngle, corrRes.maxi, corrRes.curv.x, corrRes.curv.y );
                     
                     corrMsg = s1 + wxT(" -- ") +  wxString(_("change points, or press right mouse button to add the pair"));
@@ -1098,7 +1296,23 @@ bool CPEditorPanel::PointFineTune(unsigned int tmplImgNr,
 {
     DEBUG_TRACE("tmpl img nr: " << tmplImgNr << " corr src: "
                 << subjImgNr);
-
+    if (tmplImgNr == subjImgNr)
+    {
+        // for line control points (assumed when both points are in the same image)
+        // check the distance before running fine-tune
+        // if both points are in the search area decrease search area
+        const double distance = (tmplPoint - o_subjPoint.toDiff2D()).magnitude();
+        if (distance < sWidth)
+        {
+            sWidth = 0.9 * distance;
+        };
+        if (sWidth < 1.1 * templSize)
+        {
+            MainFrame::Get()->SetStatusText(_("Distance between line control points too short, skipping fine-tune."));
+            wxBell();
+            return false;
+        };
+    };
     MainFrame::Get()->SetStatusText(_("searching similar points..."),0);
 
     double corrThresh=HUGIN_FT_CORR_THRESHOLD;
@@ -1122,12 +1336,11 @@ bool CPEditorPanel::PointFineTune(unsigned int tmplImgNr,
     res.curv.x = - res.curv.x;
     res.curv.y = - res.curv.y;
 
-    MainFrame::Get()->SetStatusText(wxString::Format(_("Point fine-tuned, angle: %.0f deg, correlation coefficient: %0.3f, curvature: %0.3f %0.3f "),
+    MainFrame::Get()->SetStatusText(wxString::Format(_("Point fine-tuned, angle: %.0f deg, correlation coefficient: %0.3f, curvature: %0.3f %0.3f"),
                                     res.maxAngle, res.maxi, res.curv.x, res.curv.y ),0);
     if (res.corrPos.x < 0 || res.corrPos.y < 0 || res.maxpos.x < 0 || res.maxpos.y < 0)
     {
         // invalid transformation in fine tune
-#if wxCHECK_VERSION(2, 9, 0)
         wxMessageDialog dlg(this,
             _("No similar point found."),
 #ifdef _WIN32
@@ -1138,21 +1351,11 @@ bool CPEditorPanel::PointFineTune(unsigned int tmplImgNr,
             wxICON_ERROR | wxOK);
         dlg.SetExtendedMessage(_("An internal transformation went wrong.\nCheck that the point is inside the image."));
         dlg.ShowModal();
-#else
-        wxMessageBox(_("An internal transformation went wrong.\nCheck that the point is inside the image."),
-#ifdef _WIN32
-            _("Hugin"),
-#else
-            wxT(""),
-#endif
-            wxICON_ERROR | wxOK, this);
-#endif
         return false;
     }
     if (res.maxi < corrThresh || res.curv.x < curvThresh || res.curv.y < curvThresh )
     {
         // Bad correlation result.
-#if wxCHECK_VERSION(2, 9, 0)
         wxMessageDialog dlg(this,
             _("No similar point found."),
 #ifdef _WIN32
@@ -1164,17 +1367,6 @@ bool CPEditorPanel::PointFineTune(unsigned int tmplImgNr,
         dlg.SetExtendedMessage(wxString::Format(_("Check the similarity visually.\nCorrelation coefficient (%.3f) is lower than the threshold set in the preferences."),
                              res.maxi));
         dlg.ShowModal();
-#else
-        wxMessageBox(
-            wxString::Format(_("No similar point found. Check the similarity visually.\nCorrelation coefficient (%.3f) is lower than the threshold set in the preferences."),
-                             res.maxi),
-#ifdef _WIN32
-            _("Hugin"),
-#else
-            wxT(""),
-#endif
-            wxICON_ERROR | wxOK, this);
-#endif
         return false;
     }
 
@@ -1216,6 +1408,21 @@ void CPEditorPanel::panoramaChanged(HuginBase::Panorama &pano)
         m_countCP = pano.getNrOfCtrlPoints();
         UpdateDisplay(false);
     };
+    // update header if necessary
+    wxListItem item;
+    if (m_cpList->GetColumn(6, item))
+    {
+        if (MainFrame::Get()->IsShowingCorrelation())
+        {
+            item.SetText(_("Correlation"));
+        }
+        else
+        {
+            item.SetText(_("Distance"));
+        }
+        m_cpList->SetColumn(6, item);
+    };
+
     DEBUG_TRACE("");
 }
 
@@ -1408,6 +1615,7 @@ void CPEditorPanel::UpdateDisplay(bool newPair)
 
     // update control points
     const HuginBase::CPVector & controlPoints = m_pano->getCtrlPoints();
+    const size_t oldCurrentPointSize = currentPoints.size();
     currentPoints.clear();
     mirroredPoints.clear();
 
@@ -1436,10 +1644,15 @@ void CPEditorPanel::UpdateDisplay(bool newPair)
     m_rightImg->update();
 
     // put these control points into our listview.
-    unsigned int selectedCP = UINT_MAX;
-    for ( int i=0; i < m_cpList->GetItemCount() ; i++ ) {
-      if ( m_cpList->GetItemState( i, wxLIST_STATE_SELECTED ) ) {
-        selectedCP = i;            // remembers the old selection
+    unsigned int selectedItem = UINT_MAX;
+    long selectedCP = -1;
+    for (int i = 0; i < m_cpList->GetItemCount(); i++)
+    {
+      if ( m_cpList->GetItemState( i, wxLIST_STATE_SELECTED))
+      {
+          selectedItem = (unsigned int) i;            // remembers the old selection, only one can be selected
+          selectedCP = m_cpList->GetItemData(i);
+          break;
       }
     }
     m_cpList->Freeze();
@@ -1448,7 +1661,9 @@ void CPEditorPanel::UpdateDisplay(bool newPair)
     for (unsigned int i=0; i < currentPoints.size(); ++i) {
         const HuginBase::ControlPoint & p(currentPoints[i].second);
         DEBUG_DEBUG("inserting LVItem " << i);
-        m_cpList->InsertItem(i,wxString::Format(wxT("%d"),i));
+        long item = m_cpList->InsertItem(i, wxString::Format(wxT("%d"), i), -1);
+        // store index in list data field
+        m_cpList->SetItemData(item, i);
         m_cpList->SetItem(i,1,wxString::Format(wxT("%.2f"),p.x1));
         m_cpList->SetItem(i,2,wxString::Format(wxT("%.2f"),p.y1));
         m_cpList->SetItem(i,3,wxString::Format(wxT("%.2f"),p.x2));
@@ -1471,13 +1686,32 @@ void CPEditorPanel::UpdateDisplay(bool newPair)
         m_cpList->SetItem(i,5,mode);
         m_cpList->SetItem(i,6,wxString::Format(wxT("%.2f"),p.error));
     }
+    SortList();
 
-    if ( selectedCP < (unsigned int) m_cpList->GetItemCount() && ! newPair) {
+    if (selectedItem <= (unsigned int)m_cpList->GetItemCount() && !newPair && m_cpList->GetItemCount() > 0)
+    {
         // sets an old selection again, only if the images have not changed
-        m_cpList->SetItemState( selectedCP,
-                                wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED );
-        m_cpList->EnsureVisible(selectedCP);
-        m_selectedPoint = selectedCP;
+        if (oldCurrentPointSize == currentPoints.size())
+        {
+            // number of control points is not changed, so select the same cp
+            // as before
+            long selected = m_cpList->FindItem(-1, selectedCP);
+            m_cpList->SetItemState(selected, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
+            m_cpList->EnsureVisible(selected);
+            m_selectedPoint = selectedCP;
+        }
+        else
+        {
+            // number of cp has change, so keep the next item seleteced
+            if (selectedItem == (unsigned int)m_cpList->GetItemCount())
+            {
+                // previously last item was selected, move selected to now last item
+                selectedItem = m_cpList->GetItemCount() - 1;
+            };
+            m_cpList->SetItemState(selectedItem, wxLIST_STATE_SELECTED, wxLIST_STATE_SELECTED);
+            m_cpList->EnsureVisible(selectedItem);
+            m_selectedPoint = m_cpList->GetItemData(selectedItem);
+        };
         EnablePointEdit(true);
 
         const HuginBase::ControlPoint & p = currentPoints[m_selectedPoint].second;
@@ -1529,7 +1763,7 @@ void CPEditorPanel::OnTextPointChange(wxCommandEvent &e)
     if (item == -1) {
         return;
     }
-    unsigned int nr = (unsigned int) item;
+    const unsigned int nr = m_cpList->GetItemData(item);
     assert(nr < currentPoints.size());
     HuginBase::ControlPoint cp = currentPoints[nr].second;
 
@@ -1602,7 +1836,7 @@ void CPEditorPanel::OnCPListSelect(wxListEvent & ev)
     int t = ev.GetIndex();
     DEBUG_TRACE("selected: " << t);
     if (t >=0) {
-        SelectLocalPoint((unsigned int) t);
+        SelectLocalPoint(m_cpList->GetItemData(t));
         changeState(NO_POINT);
     }
     EnablePointEdit(true);
@@ -1707,7 +1941,7 @@ void CPEditorPanel::OnKey(wxKeyEvent & e)
                 wxBell();
                 return;
             }
-            unsigned int pNr = localPNr2GlobalPNr((unsigned int) item);
+            unsigned int pNr = localPNr2GlobalPNr(m_cpList->GetItemData(item));
             DEBUG_DEBUG("about to delete point " << pNr);
             PanoCommand::GlobalCmdHist::getInstance().addCommand(
                 new PanoCommand::RemoveCtrlPointCmd(*m_pano,pNr)
@@ -1794,7 +2028,7 @@ void CPEditorPanel::OnDeleteButton(wxCommandEvent & e)
             return;
         }
         // get the global point number
-        unsigned int pNr = localPNr2GlobalPNr((unsigned int) item);
+        unsigned int pNr = localPNr2GlobalPNr(m_cpList->GetItemData(item));
 
         PanoCommand::GlobalCmdHist::getInstance().addCommand(
             new PanoCommand::RemoveCtrlPointCmd(*m_pano,pNr )
@@ -2057,7 +2291,7 @@ void CPEditorPanel::OnCelesteButton(wxCommandEvent & e)
             return;
         }
 
-        if(cloudCP.size()>0)
+        if(!cloudCP.empty())
         {
             PanoCommand::GlobalCmdHist::getInstance().addCommand(
                 new PanoCommand::RemoveCtrlPointsCmd(*m_pano,cloudCP)
@@ -2152,13 +2386,10 @@ hugin_utils::FDiff2D CPEditorPanel::LocalFineTunePoint(unsigned int srcNr,
     long templWidth = wxConfigBase::Get()->Read(wxT("/Finetune/TemplateSize"),HUGIN_FT_TEMPLATE_SIZE);
     long sWidth = templWidth + wxConfigBase::Get()->Read(wxT("/Finetune/LocalSearchWidth"),HUGIN_FT_LOCAL_SEARCH_WIDTH);
     vigra_ext::CorrelationResult result;
-    PointFineTune(srcNr,
-                  srcPnt,
-                  templWidth,
-                  moveNr,
-                  movePnt,
-                  sWidth,
-                  result);
+    if (!PointFineTune(srcNr, srcPnt, templWidth, moveNr, movePnt, sWidth, result))
+    {
+        return hugin_utils::FDiff2D(-1, -1);
+    };
     movedSrcPnt = result.corrPos;
     if (result.corrPos.x < 0 || result.corrPos.y < 0 || result.maxpos.x < 0 || result.maxpos.y < 0)
     {
@@ -2355,6 +2586,28 @@ void CPEditorPanel::OnColumnWidthChange( wxListEvent & e )
     wxConfigBase::Get()->Write( wxString::Format(wxT("/CPEditorPanel/ColumnWidth%d"),colNum), m_cpList->GetColumnWidth(colNum) );
 }
 
+void CPEditorPanel::OnColumnHeaderClick(wxListEvent & e)
+{
+    const int newCol = e.GetColumn();
+    if (m_sortCol == newCol)
+    {
+        m_sortAscending = !m_sortAscending;
+        SetColumnImage(m_cpList, m_sortCol, m_sortAscending ? 0 : 1);
+    }
+    else
+    {
+        if (m_sortCol != -1)
+        {
+            SetColumnImage(m_cpList, m_sortCol, -1);
+        };
+        m_sortCol = newCol;
+        SetColumnImage(m_cpList, m_sortCol, 0);
+        m_sortAscending = true;
+    }
+    SortList();
+    Refresh();
+}
+
 CPImageCtrl::ImageRotation CPEditorPanel::GetRot(double yaw, double pitch, double roll)
 {
     CPImageCtrl::ImageRotation rot = CPImageCtrl::ROT0;
