@@ -290,7 +290,7 @@ wxRect DisplayedControlPoint::DrawTextMag(wxDC& dc, wxPoint p, hugin_utils::FDif
     wxCoord tw, th;
     dc.GetTextExtent(m_label, &tw, &th);
 
-    if (drawMag)
+    if (drawMag && m_control->getScale() < 2)
     {
         wxBitmap magBitmap = m_control->generateMagBitmap(pointInput, p);
         // TODO: select position depending on visible part of canvas
@@ -839,7 +839,7 @@ wxBitmap CPImageCtrl::generateMagBitmap(hugin_utils::FDiff2D point, wxPoint canv
 
     // apply the transform
     AppBase::DummyProgressDisplay progDisp;
-    vigra_ext::transformImageIntern(vigra::srcImageRange(*(m_img->image8)),
+    vigra_ext::transformImageIntern(vigra::srcImageRange(*m_img->get8BitImage()),
                          vigra::destImageRange(magImg),
                          vigra::destImage(maskImg),
                          transform,
@@ -984,7 +984,16 @@ void CPImageCtrl::rescaleImage()
         imageSize.SetHeight(scale(imageSize.GetHeight()));
         DEBUG_DEBUG("rescaling to " << imageSize.GetWidth() << "x"
             << imageSize.GetHeight());
-        img = img.Scale(imageSize.GetWidth(), imageSize.GetHeight());
+        wxImageResizeQuality resizeQuality = wxIMAGE_QUALITY_NORMAL;
+        if (std::max(img.GetWidth(), img.GetHeight()) > (ULONG_MAX >> 16))
+        {
+            // wxIMAGE_QUALITY_NORMAL resizes the image with ResampleNearest
+            // this algorithm works only if image dimensions are smaller then 
+            // ULONG_MAX >> 16 (actual size of unsigned long differ from system
+            // to system)
+            resizeQuality = wxIMAGE_QUALITY_BOX_AVERAGE;
+        };
+        img = img.Scale(imageSize.GetWidth(), imageSize.GetHeight(), resizeQuality);
     };
     // need to rotate full image. warning. this can be very memory intensive
     if (m_imgRotation != ROT0)
@@ -1096,7 +1105,7 @@ void CPImageCtrl::showPosition(hugin_utils::FDiff2D point, bool warpPointer)
 CPImageCtrl::EditorState CPImageCtrl::isOccupied(wxPoint mousePos, const hugin_utils::FDiff2D &p, unsigned int & pointNr) const
 {
     // check if mouse is hovering over a label
-    if(m_points.size()>0)
+    if(!m_points.empty())
     {
         for(int i=m_points.size()-1; i>=0; i--)
         {
@@ -1745,6 +1754,11 @@ const wxSize CPImageCtrl::GetBitmapSize() const
     return bitmap.GetSize();
 };
 
+HuginBase::ImageCache::ImageCacheRGB8Ptr CPImageCtrl::GetImg()
+{
+    return m_img->get8BitImage();
+};
+
 IMPLEMENT_DYNAMIC_CLASS(CPImageCtrl, wxScrolledWindow)
 
 CPImageCtrlXmlHandler::CPImageCtrlXmlHandler()
