@@ -76,6 +76,10 @@ CPListCtrl::CPListCtrl() : m_pano(NULL)
 
 CPListCtrl::~CPListCtrl()
 {
+    wxConfigBase* config = wxConfig::Get();
+    config->Write(wxT("/CPListFrame/SortColumn"), m_sortCol);
+    config->Write(wxT("/CPListFrame/SortAscending"), m_sortAscend ? 1 : 0);
+    config->Flush();
     if (m_pano)
     {
         m_pano->removeObserver(this);
@@ -94,7 +98,7 @@ bool CPListCtrl::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos,
     InsertColumn(2, _("Right Img."), wxLIST_FORMAT_RIGHT, 65);
     InsertColumn(3, _("P CP#"), wxLIST_FORMAT_RIGHT, 25);
     InsertColumn(4, _("Alignment"), wxLIST_FORMAT_LEFT, 80);
-    InsertColumn(5, _("Distance"), wxLIST_FORMAT_RIGHT, 80);
+    InsertColumn(5, MainFrame::Get()->IsShowingCorrelation() ? _("Correlation") : _("Distance"), wxLIST_FORMAT_RIGHT, 80);
 
     //get saved width
     for (int j = 0; j < GetColumnCount(); j++)
@@ -107,6 +111,40 @@ bool CPListCtrl::Create(wxWindow *parent, wxWindowID id, const wxPoint& pos,
         };
     };
     EnableAlternateRowColours(true);
+
+    wxMemoryDC memDC;
+    memDC.SetFont(GetFont());
+    wxSize fontSize = memDC.GetTextExtent(wxT("\u25b3"));
+    wxCoord charSize = std::max(fontSize.GetWidth(), fontSize.GetHeight());
+    wxImageList* sortIcons = new wxImageList(charSize, charSize, true, 0);
+    {
+        wxBitmap bmp(charSize, charSize);
+        wxMemoryDC dc(bmp);
+        dc.SetBackgroundMode(wxPENSTYLE_TRANSPARENT);
+        dc.SetBackground(GetBackgroundColour());
+        dc.Clear();
+        dc.SetFont(GetFont());
+        dc.DrawText(wxT("\u25b3"), (charSize - fontSize.GetWidth()) / 2, (charSize - fontSize.GetHeight()) / 2);
+        dc.SelectObject(wxNullBitmap);
+        sortIcons->Add(bmp, GetBackgroundColour());
+    };
+    {
+        wxBitmap bmp(charSize, charSize);
+        wxMemoryDC dc(bmp);
+        dc.SetBackgroundMode(wxPENSTYLE_TRANSPARENT);
+        dc.SetBackground(GetBackgroundColour());
+        dc.Clear();
+        dc.SetFont(GetFont());
+        dc.DrawText(wxT("\u25bd"), (charSize - fontSize.GetWidth()) / 2, (charSize - fontSize.GetHeight()) / 2);
+        dc.SelectObject(wxNullBitmap);
+        sortIcons->Add(bmp, GetBackgroundColour());
+    };
+    AssignImageList(sortIcons, wxIMAGE_LIST_SMALL);
+    wxConfigBase* config = wxConfig::Get();
+    m_sortCol=config->Read(wxT("/CPListFrame/SortColumn"), 0l);
+    m_sortAscend = config->Read(wxT("/CPListFrame/SortAscending"), 1l) == 1;
+    config->Flush();
+    SetColumnImage(m_sortCol, m_sortAscend ? 0 : 1);
     return true;
 };
 
@@ -164,9 +202,27 @@ wxString CPListCtrl::OnGetItemText(long item, long column) const
     return wxEmptyString;
 };
 
+int CPListCtrl::OnGetItemImage(long item) const
+{
+    return -1;
+};
+
 void CPListCtrl::panoramaChanged(HuginBase::Panorama &pano)
 {
     m_onlyActiveImages = MainFrame::Get()->GetOptimizeOnlyActiveImages();
+    wxListItem item;
+    if (GetColumn(5, item))
+    {
+        if (MainFrame::Get()->IsShowingCorrelation())
+        {
+            item.SetText(_("Correlation"));
+        }
+        else
+        {
+            item.SetText(_("Distance"));
+        }
+        SetColumn(5, item);
+    };
     UpdateInternalCPList();
     SetItemCount(m_internalCPList.size());
     Refresh();
@@ -358,10 +414,13 @@ void CPListCtrl::OnCPListHeaderClick(wxListEvent& e)
     if (m_sortCol == newCol)
     {
         m_sortAscend = !m_sortAscend;
+        SetColumnImage(m_sortCol, m_sortAscend ? 0 : 1);
     }
     else
     {
+        ClearColumnImage(m_sortCol);
         m_sortCol = newCol;
+        SetColumnImage(m_sortCol, 0);
         m_sortAscend = true;
     }
     SortInternalList(false);
