@@ -193,6 +193,8 @@ public:
     /** dtor.
      */
     virtual ~GLPreviewFrame();
+    /** store position and size of window in wxConfig */
+    void StorePositionAndSize();
 
     virtual void panoramaChanged(HuginBase::Panorama &pano);
     virtual void panoramaImagesChanged(HuginBase::Panorama &pano, const HuginBase::UIntSet &changed);
@@ -282,6 +284,9 @@ protected:
     void OnDefaultExposure( wxCommandEvent & e );
     void OnDecreaseExposure( wxSpinEvent & e );
     void OnIncreaseExposure( wxSpinEvent & e );
+    void OnRangeCompressionIncrease(wxSpinEvent & e);
+    void OnRangeCompressionDecrease(wxSpinEvent & e);
+    void OnRangeCompressionChanged(wxCommandEvent& e);
 
     void OnBlendChoice(wxCommandEvent & e);
     void OnDragChoice(wxCommandEvent & e);
@@ -396,8 +401,9 @@ private:
     // wxChoice * m_outputModeChoice;
     wxTextCtrl * m_exposureTextCtrl;
     wxBitmapButton * m_defaultExposureBut;
-    wxTextCtrl* m_exposureText;
     wxSpinButton * m_exposureSpinBut;
+    wxTextCtrl* m_rangeCompressionTextCtrl;
+    wxSpinButton* m_rangeCompressionSpinBut;
     /// Bar for context sensitive projection information.
     wxInfoBar * m_infoBar;
     //assistant related controls
