@@ -20,10 +20,7 @@
  *
  */
 
-#ifdef __APPLE__
 #include "panoinc_WX.h"
-#endif
-
 #include "base_wx/wxutils.h"
 
 #include "panoinc.h"
@@ -347,11 +344,13 @@ void GLViewer::Resized(wxSizeEvent& e)
         DEBUG_DEBUG("RESIZED_IN_SHOWN");
         if (m_renderer)
         {
-          int w, h;
           DEBUG_DEBUG("RESIZED_IN_RENDERER");
-          GetClientSize(&w, &h);    
+          wxSize clientSize = GetClientSize();
+#if defined __WXGTK3__
+          clientSize*=GetContentScaleFactor();
+#endif
           SetUpContext();
-          offset = m_renderer->Resize(w, h);
+          offset = m_renderer->Resize(clientSize.GetWidth(), clientSize.GetHeight());
           Redraw();
         };
     }
@@ -370,15 +369,17 @@ void GLViewer::Redraw()
 #if defined __WXMAC__ && wxCHECK_VERSION(3,1,0) 
     wxColour col(128,128,128);
 #else
-    wxColour col = wxSystemSettings::GetColour(wxSYS_COLOUR_APPWORKSPACE);
+    wxColour col = wxSystemSettings::GetColour(wxSYS_COLOUR_BTNFACE);
 #endif
     m_renderer->SetBackground(col.Red(), col.Green(), col.Blue());
     if (m_visualization_state->RequireRecalculateViewport())
     {
         // resize the viewport in case the panorama dimensions have changed.
-        int w, h;
-        GetClientSize(&w, &h);
-        offset = m_renderer->Resize(w, h);
+        wxSize clientSize = GetClientSize();
+#if defined __WXGTK3__
+        clientSize *= GetContentScaleFactor();
+#endif
+        offset = m_renderer->Resize(clientSize.GetWidth(), clientSize.GetHeight());
     }
     m_visualization_state->DoUpdates();
     m_renderer->Redraw();
