@@ -292,7 +292,7 @@ void ImagesPanel::CPGenerate(wxCommandEvent & e)
     HuginBase::UIntSet selImg = m_images_tree->GetSelectedImages();
     //if only one image is selected, run detector on all images, except for linefind
     wxString progName = cpdetector_config.settings[m_CPDetectorChoice->GetSelection()].GetProg().Lower();
-    if ((selImg.size() == 0) || (selImg.size() == 1 && progName.Find(wxT("linefind")) == wxNOT_FOUND))
+    if ((selImg.empty()) || (selImg.size() == 1 && progName.Find(wxT("linefind")) == wxNOT_FOUND))
     {
         // add all images.
         selImg.clear();
@@ -354,7 +354,7 @@ void ImagesPanel::OnSelectionChanged(wxTreeEvent & e)
 {
     const HuginBase::UIntSet & sel = m_images_tree->GetSelectedImages();
     DEBUG_DEBUG("selected Images: " << sel.size());
-    if (sel.size() == 0)
+    if (sel.empty())
     {
         // nothing to edit
         DisableImageCtrls();
@@ -494,7 +494,16 @@ void ImagesPanel::UpdatePreviewImage()
         // Make sure the size is positive:
         // on a small window, m_smallImgCtrl can have 0 width.
         sz.IncTo(wxSize(1,1));
-        wxImage scaled = img.Scale(sz.GetWidth(),sz.GetHeight());
+        wxImageResizeQuality resizeQuality = wxIMAGE_QUALITY_NORMAL;
+        if (std::max(img.GetWidth(), img.GetHeight()) > (ULONG_MAX >> 16))
+        {
+            // wxIMAGE_QUALITY_NORMAL resizes the image with ResampleNearest
+            // this algorithm works only if image dimensions are smaller then 
+            // ULONG_MAX >> 16 (actual size of unsigned long differ from system
+            // to system)
+            resizeQuality = wxIMAGE_QUALITY_BOX_AVERAGE;
+        };
+        wxImage scaled = img.Scale(sz.GetWidth(),sz.GetHeight(), resizeQuality);
         // now apply color profile
         if (!cacheEntry->iccProfile->empty() || huginApp::Get()->HasMonitorProfile())
         {
@@ -519,7 +528,7 @@ void ImagesPanel::OnLensTypeChanged (wxCommandEvent & e)
 {
     size_t var = GetSelectedValue(m_lenstype);
     HuginBase::UIntSet images = m_images_tree->GetSelectedImages();
-    if(images.size()>0)
+    if(!images.empty())
     {
         const HuginBase::SrcPanoImage & img = m_pano->getImage(*(images.begin()));
         double focal_length = HuginBase::SrcPanoImage::calcFocalLength(img.getProjection(), img.getHFOV(), img.getCropFactor(), img.getSize());
