@@ -16,8 +16,8 @@
  *  General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public
- *  License along with this software; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  License along with this software. If not, see
+ *  <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -35,7 +35,7 @@ LayoutRemapper::LayoutRemapper(HuginBase::Panorama *m_pano,
                                HuginBase::SrcPanoImage* image,
                                VisualizationState *visualization_state)
         :MeshRemapper(m_pano, image, visualization_state),
-         scale(0)
+         m_layoutScale(0)
         
 {
     // We'll never use any different texture coordinates, so record them now:
@@ -76,11 +76,11 @@ void LayoutRemapper::UpdateAndResetIndex()
     double preview_width, preview_height;
     if (landscape)
     {
-        preview_width = scale;
-        preview_height = scale / image_width * image_height;
+        preview_width = m_layoutScale;
+        preview_height = m_layoutScale / image_width * image_height;
     } else {
-        preview_height = scale;
-        preview_width = scale / image_height * image_width;
+        preview_height = m_layoutScale;
+        preview_width = m_layoutScale / image_height * image_width;
     }
     
     // find bounds for image drawing
@@ -127,5 +127,5 @@ bool LayoutRemapper::GetNextFaceCoordinates(Coords *result)
 
 void LayoutRemapper::setScale(double scale_in)
 {
-    scale = scale_in;
+    m_layoutScale = scale_in;
 }
