@@ -493,10 +493,8 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
                     {
                         // read descriptions from file
                         wxFileConfig executorFile(inputStream);
-                        wxString desc = executorFile.Read(wxT("/General/Description"), wxEmptyString);
-                        desc = desc.Trim(true).Trim(false);
-                        wxString help = executorFile.Read(wxT("/General/Help"), wxEmptyString);
-                        help = help.Trim(true).Trim(false);
+                        wxString desc = HuginQueue::GetSettingStringTranslated(&executorFile, wxT("/General/Description"), wxEmptyString);
+                        wxString help = HuginQueue::GetSettingStringTranslated(&executorFile, wxT("/General/Help"), wxEmptyString);
                         if (help.IsEmpty())
                         {
                             help = wxString::Format(_("User defined sequence: %s"), file);
@@ -551,9 +549,8 @@ MainFrame::MainFrame(wxWindow* parent, HuginBase::Panorama & pano)
                     {
                         // read descriptions from file
                         wxFileConfig assistantFile(inputStream);
-                        wxString desc = assistantFile.Read(wxT("/General/Description"), wxEmptyString);
-                        desc = desc.Trim(true).Trim(false);
-                        wxString help = assistantFile.Read(wxT("/General/Help"), wxEmptyString);
+                        wxString desc = HuginQueue::GetSettingStringTranslated(&assistantFile, wxT("/General/Description"), wxEmptyString);
+                        wxString help = HuginQueue::GetSettingStringTranslated(&assistantFile, wxT("/General/Help"), wxEmptyString);
                         help = help.Trim(true).Trim(false);
                         if (help.IsEmpty())
                         {
@@ -993,13 +990,13 @@ void MainFrame::OnSaveProject(wxCommandEvent & e)
         {
             if(gl_preview_frame)
             {
-                gl_preview_frame->SetTitle(scriptName.GetName() + wxT(".") + scriptName.GetExt() + wxT(" - ") + _("Hugin - Panorama Stitcher"));
+                gl_preview_frame->SetTitle(scriptName.GetName() + wxT(".") + scriptName.GetExt() + wxT(" - ") + _("Hugin - Panorama Creator"));
             };
             SetTitle(scriptName.GetName() + wxT(".") + scriptName.GetExt() + wxT(" - ") + _("Panorama editor"));
         }
         else
         {
-            SetTitle(scriptName.GetName() + wxT(".") + scriptName.GetExt() + wxT(" - ") + _("Hugin - Panorama Stitcher"));
+            SetTitle(scriptName.GetName() + wxT(".") + scriptName.GetExt() + wxT(" - ") + _("Hugin - Panorama Creator"));
         };
 
         pano.clearDirty();
@@ -1872,6 +1869,11 @@ void MainFrame::OnFineTuneAll(wxCommandEvent & e)
                         cps[*it].error = res.maxi;
                     }
                 }
+                else
+                {
+                    // for line control points set error = correlation to 1
+                    cps[*it].error = 1.0;
+                };
                 unsigned int rm = *it;
                 ++it;
                 unoptimized.erase(rm);
