@@ -24,11 +24,7 @@
  *
  */
 
-// often necessary before panoinc.h
-#ifdef __APPLE__
 #include "panoinc_WX.h"
-#endif
-
 #include "panoinc.h"
 #include <hugin_utils/stl_utils.h>
 
@@ -222,7 +218,8 @@ MaskEditorPanel::~MaskEditorPanel()
     config->Write(wxT("/MaskEditorPanel/ShowActiveMasks"),XRCCTRL(*this,"mask_editor_show_active_masks",wxCheckBox)->GetValue());
     config->Write(wxT("/MaskEditorPanel/DefaultMaskType"),(long)m_defaultMaskType);
     config->Write(wxT("/MaskEditorPanel/CropImagesLens"), m_cropLens->GetValue());
-    
+    config->Flush();
+
     DEBUG_TRACE("dtor");
     if (m_imageGroups)
     {
@@ -233,7 +230,7 @@ MaskEditorPanel::~MaskEditorPanel()
 
 size_t MaskEditorPanel::GetImgNr()
 {
-    if(m_selectedImages.size()==0)
+    if(m_selectedImages.empty())
     {
         return UINT_MAX;
     }
@@ -395,7 +392,7 @@ void MaskEditorPanel::panoramaImagesChanged(HuginBase::Panorama &pano, const Hug
             };
     };
 
-    if (m_selectedImages.size() > 0)
+    if (!m_selectedImages.empty())
     {
         if (set_contains(changed, GetImgNr()))
         {
@@ -416,7 +413,7 @@ void MaskEditorPanel::OnImageSelect(wxListEvent &e)
     setMask(UINT_MAX);
     setImage(GetImgNr());
 
-    bool hasImage = (m_selectedImages.size() > 0);
+    const bool hasImage = !m_selectedImages.empty();
     m_left_textctrl->Enable(hasImage);
     m_top_textctrl->Enable(hasImage);
     m_bottom_textctrl->Enable(hasImage);
@@ -507,7 +504,7 @@ void MaskEditorPanel::OnMaskLoad(wxCommandEvent &e)
         HuginBase::MaskPolygonVector loadedMasks;
         LoadMaskFromStream(in, maskImageSize, loadedMasks, GetImgNr());
         in.close();
-        if(maskImageSize.area()==0 || loadedMasks.size()==0)
+        if(maskImageSize.area()==0 || loadedMasks.empty())
         {
             wxMessageBox(wxString::Format(_("Could not parse mask from file %s."),dlg.GetPath().c_str()),_("Warning"),wxOK | wxICON_EXCLAMATION,this);
             return;
@@ -564,7 +561,7 @@ void MaskEditorPanel::OnMaskPaste(wxCommandEvent &e)
                 LoadMaskFromStream(stream, maskImageSize, loadedMasks, GetImgNr());
             }
             wxTheClipboard->Close();
-            if(maskImageSize.area()==0 || loadedMasks.size()==0)
+            if(maskImageSize.area()==0 || loadedMasks.empty())
             {
                 wxBell();
                 return;
@@ -646,6 +643,10 @@ void MaskEditorPanel::OnZoom(wxCommandEvent & e)
     {
         m_editImg->Scroll(posX*factor - ctrlSize.GetWidth() / 2, posY*factor - ctrlSize.GetHeight() / 2);
     };
+    if (e.GetString() == "update_selection")
+    {
+        XRCCTRL(*this, "mask_editor_choice_zoom", wxChoice)->SetSelection(e.GetSelection());
+    };
 }
 
 void MaskEditorPanel::OnColourChanged(wxColourPickerEvent &e)
@@ -681,7 +682,7 @@ void MaskEditorPanel::UpdateMaskList(bool restoreSelection)
     m_maskList->Freeze();
     if(GetImgNr()<UINT_MAX)
     {
-        if(m_currentMasks.size()>0)
+        if(!m_currentMasks.empty())
         {
             if(m_maskList->GetItemCount()!=m_currentMasks.size())
             {
