@@ -271,6 +271,7 @@ PanoPanel::~PanoPanel(void)
 {
     DEBUG_TRACE("dtor");
     wxConfigBase::Get()->Write(wxT("Stitcher/DefaultRemapper"),m_RemapperChoice->GetSelection());
+    wxConfigBase::Get()->Flush();
 
     m_HFOVText->PopEventHandler(true);
     m_VFOVText->PopEventHandler(true);
@@ -371,7 +372,7 @@ void PanoPanel::UpdateDisplay(const HuginBase::PanoramaOptions & opt, const bool
     m_VFOVText->ChangeValue(wxString(val.c_str(), wxConvLocal));
 
     // disable VFOV edit field, due to bugs in setHeight(), setWidth()
-    bool hasImages = pano->getActiveImages().size() > 0;
+    const bool hasImages = !pano->getActiveImages().empty();
     m_VFOVText->Enable(m_keepViewOnResize);
     m_CalcOptWidthButton->Enable(m_keepViewOnResize && hasImages);
     m_CalcHFOVButton->Enable(m_keepViewOnResize && hasImages);
@@ -866,7 +867,7 @@ void PanoPanel::OnRemapperOptions(wxCommandEvent & e)
                 );
         }
     } else {
-        wxLogError(_(" PTmender options not yet implemented"));
+        wxLogError(_("PTmender options not yet implemented"));
     }
 }
 
@@ -892,13 +893,7 @@ void PanoPanel::OnBlenderOptions(wxCommandEvent & e)
         dlg.CentreOnParent();
 
         if (dlg.ShowModal() == wxID_OK) {
-            if (enblend_opts_text->GetValue().length() > 0) {
-                opt.enblendOptions = enblend_opts_text->GetValue().mb_str(wxConvLocal);
-            }
-            else
-            {
-                opt.enblendOptions = wxConfigBase::Get()->Read(wxT("Enblend/Args"),wxT(HUGIN_ENBLEND_ARGS)).mb_str(wxConvLocal);
-            };
+            opt.enblendOptions = enblend_opts_text->GetValue().mb_str(wxConvLocal);
             PanoCommand::GlobalCmdHist::getInstance().addCommand(
                 new PanoCommand::SetPanoOptionsCmd( *pano, opt )
                 );
@@ -936,7 +931,7 @@ void PanoPanel::OnBlenderOptions(wxCommandEvent & e)
         }
         else
         {
-            wxLogError(_(" PTblender options not yet implemented"));
+            wxLogError(_("PTblender options not yet implemented"));
         };
     };
 }
@@ -958,13 +953,7 @@ void PanoPanel::OnFusionOptions(wxCommandEvent & e)
     dlg.CentreOnParent();
 
     if (dlg.ShowModal() == wxID_OK) {
-        if (enfuse_opts_text->GetValue().length() > 0) {
-            opt.enfuseOptions = enfuse_opts_text->GetValue().mb_str(wxConvLocal);
-        }
-        else
-        {
-            opt.enfuseOptions = wxConfigBase::Get()->Read(wxT("Enfuse/Args"),wxT(HUGIN_ENFUSE_ARGS)).mb_str(wxConvLocal);
-        };
+        opt.enfuseOptions = enfuse_opts_text->GetValue().mb_str(wxConvLocal);
         PanoCommand::GlobalCmdHist::getInstance().addCommand(
             new PanoCommand::SetPanoOptionsCmd( *pano, opt )
             );
@@ -992,7 +981,7 @@ void PanoPanel::OnHDRMergeOptions(wxCommandEvent & e)
                 );
         }
     } else {
-        wxLogError(_(" Options for this HDRMerge program not yet implemented"));
+        wxLogError(_("Options for this HDRMerge program not yet implemented"));
     }
 }
 
@@ -1001,7 +990,7 @@ void PanoPanel::OnHDRMergeOptions(wxCommandEvent & e)
 void PanoPanel::DoCalcFOV(wxCommandEvent & e)
 {
     DEBUG_TRACE("");
-    if (pano->getActiveImages().size() == 0) return;
+    if (pano->getActiveImages().empty()) return;
 
     HuginBase::PanoramaOptions opt = pano->getOptions();
     HuginBase::CalculateFitPanorama fitPano(*pano);
@@ -1022,7 +1011,7 @@ void PanoPanel::DoCalcFOV(wxCommandEvent & e)
 
 void PanoPanel::DoCalcOptimalWidth(wxCommandEvent & e)
 {
-    if (pano->getActiveImages().size() == 0) return;
+    if (pano->getActiveImages().empty()) return;
 
     HuginBase::PanoramaOptions opt = pano->getOptions();
     double sizeFactor = 1.0;
@@ -1046,7 +1035,7 @@ void PanoPanel::DoCalcOptimalWidth(wxCommandEvent & e)
 void PanoPanel::DoCalcOptimalROI(wxCommandEvent & e)
 {
     DEBUG_INFO("Dirty ROI Calc\n");
-    if (pano->getActiveImages().size() == 0)
+    if (pano->getActiveImages().empty())
     {
         return;
     };
@@ -1096,7 +1085,7 @@ void PanoPanel::DoStitch()
         if(tempDir.Last()!=wxFileName::GetPathSeparator())
             tempDir.Append(wxFileName::GetPathSeparator());
     wxString currentPTOfn = wxFileName::CreateTempFileName(tempDir+wxT("huginpto_"));
-    if(currentPTOfn.size() == 0) {
+    if(currentPTOfn.empty()) {
         wxMessageBox(_("Could not create temporary project file"),_("Error"),
                 wxCANCEL | wxICON_ERROR,this);
         return;
@@ -1382,7 +1371,7 @@ void PanoPanel::DoUserDefinedStitch(const wxString& settings)
         }
     };
     wxString currentPTOfn = wxFileName::CreateTempFileName(tempDir + wxT("huginpto_"));
-    if (currentPTOfn.size() == 0)
+    if (currentPTOfn.empty())
     {
         wxMessageBox(_("Could not create temporary project file"), _("Error"),
             wxCANCEL | wxICON_ERROR, this);
@@ -1733,7 +1722,7 @@ bool PanoPanel::CheckGoodSize()
 bool PanoPanel::CheckHasImages()
 {
     HuginBase::UIntSet images=getImagesinROI(*pano, pano->getActiveImages());
-    if(images.size()==0)
+    if(images.empty())
     {
         wxMessageBox(_("There are no active images in the output region.\nPlease check your settings, so that at least one image is in the output region."),
 #ifdef _WIN32
@@ -1743,7 +1732,7 @@ bool PanoPanel::CheckHasImages()
 #endif
             wxOK | wxICON_INFORMATION);
     };
-    return images.size()>0;
+    return !images.empty();
 };
 
 bool PanoPanel::CheckFreeSpace(const wxString& folder)
