@@ -23,7 +23,7 @@
 #include "panoinc.h"
 
 #include "PreviewIdentifyTool.h"
-#include <config.h>
+#include "hugin_config.h"
 
 #include "base_wx/platform.h"
 #include "GLPreviewFrame.h"
@@ -70,13 +70,8 @@ wxBitmap GenerateFontTexture(const int textureHeight, int& textureWidth, std::ve
     wxMemoryDC dc(bitmap);
     dc.SetBackground(*wxBLACK_BRUSH);
     dc.Clear();
-#if wxCHECK_VERSION(3,0,0)
     wxFont font(wxSize(0, textureHeight), wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_BOLD);
     dc.SetFont(font);
-#else
-    wxFont* font=wxFont::New(wxSize(0, textureHeight), wxFONTFAMILY_DEFAULT, wxFONTSTYLE_NORMAL, wxFONTWEIGHT_BOLD, false, wxT(""));
-    dc.SetFont(*font);
-#endif    
     dc.SetTextForeground(*wxWHITE);
     dc.DrawText(wxT("0123456789"), 0, 0);
     textureWidth = 0;
@@ -89,9 +84,6 @@ wxBitmap GenerateFontTexture(const int textureHeight, int& textureWidth, std::ve
         textureWidth += textSize.GetWidth();
         glyphWidth[i] = textSize.GetWidth();
     };
-#if !wxCHECK_VERSION(3,0,0)
-    delete font;
-#endif  
     dc.SelectObject(wxNullBitmap);
     return bitmap;
 }
@@ -502,49 +494,44 @@ void PreviewIdentifyTool::AfterDrawImagesEvent()
         // this code works only for the preview window, not for the panosphere or mosaic plane
         if (m_showNumbers)
         {
-        HuginBase::PanoramaOptions* opts = helper->GetViewStatePtr()->GetOptions();
-        HuginBase::SrcPanoImage* img = helper->GetViewStatePtr()->GetSrcImage(*it);
-        HuginBase::PTools::Transform transform;
-        transform.createInvTransform(*img, *opts);
-        hugin_utils::FDiff2D imageCenter(crop_region.upperLeft() + crop_region.size() / 2);
-        hugin_utils::FDiff2D imageCenterPano;
-        if (transform.transformImgCoord(imageCenterPano, imageCenter) && !wxGetKeyState(WXK_ALT))
-        {
-            glBindTexture(GL_TEXTURE_2D, font_tex);
-            if (helper->GetViewStatePtr()->GetSupportMultiTexture())
+            HuginBase::PanoramaOptions* opts = helper->GetViewStatePtr()->GetOptions();
+            HuginBase::SrcPanoImage* img = helper->GetViewStatePtr()->GetSrcImage(*it);
+            HuginBase::PTools::Transform transform;
+            transform.createInvTransform(*img, *opts);
+            hugin_utils::FDiff2D imageCenter(crop_region.upperLeft() + crop_region.size() / 2);
+            hugin_utils::FDiff2D imageCenterPano;
+            if (transform.transformImgCoord(imageCenterPano, imageCenter) && !wxGetKeyState(WXK_ALT))
             {
-                glActiveTexture(GL_TEXTURE1);
-                glDisable(GL_TEXTURE_2D);
-                glActiveTexture(GL_TEXTURE0);
+                glBindTexture(GL_TEXTURE_2D, font_tex);
+                if (helper->GetViewStatePtr()->GetSupportMultiTexture())
+                {
+                    glActiveTexture(GL_TEXTURE1);
+                    glDisable(GL_TEXTURE_2D);
+                    glActiveTexture(GL_TEXTURE0);
+                };
+                glMatrixMode(GL_MODELVIEW);
+                glPushMatrix();
+                wxString number;
+                number << *it;
+                int textWidth = 0;
+                unsigned char* listIndex = new unsigned char[number.Length()];
+                for (size_t i = 0; i < number.Length(); ++i)
+                {
+                    textWidth += m_glyphWidth[number[i].GetValue() - 48];
+                    listIndex[i] = number[i].GetValue() - 48;
+                }
+                float scaleFactor = std::min(canvasWidth, canvasHeight) / static_cast<float>(FONT_TEXTURE_HEIGHT) / 10;
+                imageCenterPano.x = std::min<double>(std::max<double>(imageCenterPano.x, textWidth*scaleFactor / 2.0), canvasWidth - textWidth * scaleFactor / 2.0);
+                imageCenterPano.y = std::min<double>(std::max<double>(imageCenterPano.y, FONT_TEXTURE_HEIGHT*scaleFactor / 2.0), canvasHeight - FONT_TEXTURE_HEIGHT * scaleFactor / 2.0);
+                glTranslatef(imageCenterPano.x, imageCenterPano.y, 0);
+                glScalef(scaleFactor, scaleFactor, 1.0);
+                glTranslatef(-textWidth / 2, -FONT_TEXTURE_HEIGHT / 2, 0);
+                glListBase(font_list);
+                glCallLists(number.Length(), GL_UNSIGNED_BYTE, listIndex);
+                glMatrixMode(GL_MODELVIEW);
+                glPopMatrix();
+                delete[] listIndex;
             };
-            glMatrixMode(GL_MODELVIEW);
-            glPushMatrix();
-            wxString number;
-            number << *it;
-            int textWidth = 0;
-            unsigned char* listIndex = new unsigned char[number.Length()];
-            for (size_t i = 0; i < number.Length(); ++i)
-            {
-#if wxCHECK_VERSION(3,0,0)
-                textWidth += m_glyphWidth[number[i].GetValue() - 48];
-                listIndex[i] = number[i].GetValue() - 48;
-#else
-                textWidth += m_glyphWidth[number[i] - 48];
-                listIndex[i] = number[i] - 48;
-#endif
-            }
-            float scaleFactor = std::min(canvasWidth, canvasHeight) / static_cast<float>(FONT_TEXTURE_HEIGHT) / 10;
-            imageCenterPano.x = std::min<double>(std::max<double>(imageCenterPano.x, textWidth*scaleFactor / 2.0), canvasWidth - textWidth * scaleFactor / 2.0);
-            imageCenterPano.y = std::min<double>(std::max<double>(imageCenterPano.y, FONT_TEXTURE_HEIGHT*scaleFactor / 2.0), canvasHeight - FONT_TEXTURE_HEIGHT * scaleFactor / 2.0);
-            glTranslatef(imageCenterPano.x, imageCenterPano.y, 0);
-            glScalef(scaleFactor, scaleFactor, 1.0);
-            glTranslatef(-textWidth / 2, -FONT_TEXTURE_HEIGHT / 2, 0);
-            glListBase(font_list);
-            glCallLists(number.Length(), GL_UNSIGNED_BYTE, listIndex);
-            glMatrixMode(GL_MODELVIEW);
-            glPopMatrix();
-            delete[] listIndex;
-        };
         };
     }
     // set stuff back how we found it.
