@@ -29,10 +29,6 @@
 
 #include <string>
 #include "ProjectArray.h"
-#include <wx/dir.h>
-#ifndef __WXMSW__
-#include <sys/wait.h>
-#endif
 #include "RunStitchFrame.h"
 #if wxCHECK_VERSION(3,1,0)
 #include <wx/power.h>
@@ -109,17 +105,6 @@ public:
     bool IsRunning();
     /** Returns true if batch execution is currently paused */
     bool  IsPaused();
-    /** Returns last saved batch file */
-    const wxString GetLastFile()
-    {
-        return m_lastFile;
-    };
-    wxDateTime GetLastFileDate()
-    {
-        return m_lastmod;
-    };
-    /** Used in console mode. Prints out all projects and their statuses to the console */
-    void  ListBatch();
     /** Clears current batch list and loads projects from batch file */
     int  LoadBatchFile(wxString file);
     /** Loads temporary batch file */
@@ -171,9 +156,6 @@ private:
     ProjectArray  m_projList;
     //list of projects in progress
     FrameArray    m_stitchFrames;
-    //last saved ptbt file
-    wxString m_lastFile;
-    wxDateTime m_lastmod;
 
     //batch state flags
     bool m_cancelled;
