@@ -36,8 +36,7 @@
 // workaround for a conflict between exiv2 and wxWidgets/CMake built
 #define HAVE_PID_T 1
 #endif
-#include "exiv2/exiv2.hpp"
-#include "exiv2/preview.hpp"
+#include <exiv2/exiv2.hpp>
 #ifdef _WIN32
 #include <commctrl.h>
 #endif
@@ -595,11 +594,11 @@ void FindPanoDialog::SearchInDir(wxString dirstring, const bool includeSubdir, c
         m_button_send->Enable(!m_panos.empty());
         if(!m_panos.empty())
         {
-            m_statustext->SetLabel(wxString::Format(_("Found %d possible panoramas."), static_cast<int>(m_panos.size())));
+            m_statustext->SetLabel(wxString::Format(_("Found %d possible panoramas"), static_cast<int>(m_panos.size())));
         }
         else
         {
-            m_statustext->SetLabel(_("No possible panoramas found."));
+            m_statustext->SetLabel(_("No possible panoramas found"));
         };
         TIFFSetWarningHandler(m_oldtiffwarning);
     };
@@ -951,7 +950,11 @@ void PossiblePano::PopulateListCtrl(wxListCtrl* list, wxImageList* thumbs, wxArr
     wxBusyCursor cursor;
     for (ImageSet::iterator it = m_images.begin(); it != m_images.end(); ++it)
     {
+#if defined EXIV2_VERSION && EXIV2_TEST_VERSION(0,27,99)
+        Exiv2::Image::UniquePtr image;
+#else
         Exiv2::Image::AutoPtr image;
+#endif
         bool opened = false;
         try
         {
@@ -961,11 +964,20 @@ void PossiblePano::PopulateListCtrl(wxListCtrl* list, wxImageList* thumbs, wxArr
         catch (...)
         {
             std::cerr << __FILE__ << " " << __LINE__ << " Error opening file" << std::endl;
+            continue;
         }
         int index = -1;
         if (opened)
         {
-            image->readMetadata();
+            try
+            {
+                image->readMetadata();
+            }
+            catch (const Exiv2::Error& e)
+            {
+                std::cerr << __FILE__ << " " << __LINE__ << " Exiv2: Error reading metadata (" << e.what() << ")" << std::endl;
+                continue;
+            }
             // read all thumbnails
             Exiv2::PreviewManager previews(*image);
             Exiv2::PreviewPropertiesList lists = previews.getPreviewProperties();
