@@ -48,14 +48,7 @@
 #include <hugin_config.h>
 #endif
 #include <algorithm>
-#ifdef HAVE_STD_FILESYSTEM
-#include <filesystem>
-namespace fs = std::tr2::sys;
-#else
-#define BOOST_FILESYSTEM_VERSION 3
-#include <boost/filesystem.hpp>
-namespace fs = boost::filesystem;
-#endif
+#include <hugin_utils/filesystem.h>
 #include <lcms2.h>
 
 #ifdef __APPLE__
@@ -413,23 +406,13 @@ std::string GetDataDir()
 #ifdef _WIN32
     char buffer[MAX_PATH];//always use MAX_PATH for filepaths
     GetModuleFileName(NULL,buffer,sizeof(buffer));
-    std::string working_path(buffer);
-    std::string data_path("");
-    //remove filename
-    std::string::size_type pos=working_path.rfind("\\");
-    if(pos!=std::string::npos)
+    fs::path data_path(buffer);
+    data_path.remove_filename();
+    if (data_path.has_parent_path())
     {
-        working_path.erase(pos);
-        //remove last dir: should be bin
-        pos=working_path.rfind("\\");
-        if(pos!=std::string::npos)
-        {
-            working_path.erase(pos);
-            //append path delimiter and path
-            working_path.append("\\share\\hugin\\data\\");
-            data_path=working_path;
-        }
-    }
+        return (data_path.parent_path() / "share/hugin/data").string() + "\\";
+    };
+    return std::string();
 #elif defined MAC_SELF_CONTAINED_BUNDLE
     char path[PATH_MAX + 1];
     uint32_t size = sizeof(path);
@@ -439,12 +422,41 @@ std::string GetDataDir()
         data_path=dirname(path);
         data_path.append("/../Resources/xrc/");
     }
-#else
-    std::string data_path = (INSTALL_DATA_DIR);
-#endif
     return data_path;
+#elif defined UNIX_SELF_CONTAINED_BUNDLE
+    fs::path data_path = fs::read_symlink("/proc/self/exe");
+    data_path.remove_filename();
+    if (data_path.has_parent_path())
+    {
+        return (data_path.parent_path() / "share/hugin/data").string() + "/";
+    };
+    return std::string();
+#else
+    return std::string(INSTALL_DATA_DIR);
+#endif
 };
 
+#ifndef _WIN32
+std::string GetHomeDir()
+{
+    char *homedir = getenv("HOME");
+    struct passwd *pw;
+    if (homedir == NULL)
+    {
+        pw = getpwuid(getuid());
+        if (pw != NULL)
+        {
+            homedir = pw->pw_dir;
+        };
+    };
+    if (homedir == NULL)
+    {
+        return std::string();
+    };
+    return std::string(homedir);
+}
+#endif
+
 std::string GetUserAppDataDir()
 {
     fs::path path;
@@ -457,24 +469,38 @@ std::string GetUserAppDataDir()
     path = fs::path(fullpath);
     path /= "hugin";
 #else
-    char *homedir = getenv("HOME");
-    struct passwd *pw;
-    if (homedir == NULL)
+#ifdef USE_XDG_DIRS
+    char *xdgDataDir = getenv("XDG_DATA_HOME");
+    if (strlen(xdgDataDir) == 0)
     {
-        pw = getpwuid(getuid());
-        if(pw != NULL)
+        // no XDG_DATA_HOME enviroment variable set
+        // use $HOME/.local/share instead
+        const  std::string homeDir = GetHomeDir();
+        if (homeDir.empty())
         {
-            homedir = pw->pw_dir;
+            return std::string();
         };
+        path = fs::path(homeDir);
+        path /= ".local/share/hugin";
+    }
+    else
+    {
+        // XDG_DATA_HOME set, use hugindata sub directory
+        path = fs::path(xdgDataDir);
+        path /= "hugin";
     };
-    if(homedir == NULL)
+#else
+    // old behaviour, save in users home directory, sub-directory .hugindata
+    const std::string homeDir = GetHomeDir();
+    if (homeDir.empty())
     {
         return std::string();
     };
-    path = fs::path(homedir);
+    path = fs::path(homeDir);
     // we have already a file with name ".hugin" for our wxWidgets settings
     // therefore we use directory ".hugindata" in homedir
     path /= ".hugindata";
+#endif
 #endif
     if (!fs::exists(path))
     {
@@ -593,6 +619,91 @@ void DestroyContext()
     glutDestroyWindow(GlutWindowHandle);
 }
 
+#else
+#if defined HAVE_EGL && HAVE_EGL
+#include <EGL/egl.h>
+
+struct ContextSettings
+{
+    EGLDisplay m_display;
+    EGLContext m_context;
+};
+
+static ContextSettings context;
+
+static const EGLint configAttribs[] = {
+    EGL_BLUE_SIZE, 8,
+    EGL_GREEN_SIZE, 8,
+    EGL_RED_SIZE, 8,
+    EGL_ALPHA_SIZE, 8,
+    EGL_RENDERABLE_TYPE, EGL_OPENGL_BIT,
+    EGL_CONFORMANT, EGL_OPENGL_BIT, 
+    EGL_COLOR_BUFFER_TYPE, EGL_RGB_BUFFER,
+    EGL_NONE
+};
+
+bool CreateContext(int *argcp, char **argv)
+{
+    // get display connection
+    context.m_display = eglGetDisplay(EGL_DEFAULT_DISPLAY);
+    if (context.m_display == EGL_NO_DISPLAY)
+    {
+        std::cerr << "Could not connect to EGL_DEFAULT_DISPLAY" << std::endl;
+        return false;
+    };
+    // initialize egl
+    EGLint major, minor;
+    if (eglInitialize(context.m_display, &major, &minor) != EGL_TRUE)
+    {
+        std::cerr << "Could not initialize EGL" << std::endl
+            << "Error: 0x" << std::hex << eglGetError() << std::endl;
+        return false;
+    };
+    std::cout << "Init OpenGL ES " << major << "." << minor << std::endl;
+    std::cout << "Client API: " << eglQueryString(context.m_display, EGL_CLIENT_APIS) << std::endl
+        << "Vendor: " << eglQueryString(context.m_display, EGL_VENDOR) << std::endl
+        << "Version: " << eglQueryString(context.m_display, EGL_VERSION) << std::endl
+        << "EGL Extensions: " << eglQueryString(context.m_display, EGL_EXTENSIONS) << std::endl;
+    // bind OpenGL API (not OpenGL ES)
+    if (!eglBindAPI(EGL_OPENGL_API))
+    {
+        std::cerr << "Could not bind OpenGL API" << std::endl
+            << "Error: 0x" << std::hex << eglGetError() << std::endl;
+        return false;
+    };
+    // choose config
+    EGLint numConfigs;
+    EGLConfig egl_config;
+    if (eglChooseConfig(context.m_display, configAttribs, &egl_config, 1, &numConfigs) != EGL_TRUE)
+    {
+        std::cerr << "Cound not set egl config" << std::endl
+            << "Error: 0x" << std::hex << eglGetError() << std::endl;
+        return false;
+    };
+    // create surface
+    // create context and make it current
+    context.m_context = eglCreateContext(context.m_display, egl_config, EGL_NO_CONTEXT, NULL);
+    if (context.m_context == EGL_NO_CONTEXT)
+    {
+        std::cerr << "Cound not create context" << std::endl
+            << "Error: 0x" << std::hex << eglGetError() << std::endl;
+        return false;
+    };
+    if (eglMakeCurrent(context.m_display, EGL_NO_SURFACE, EGL_NO_SURFACE, context.m_context) != EGL_TRUE)
+    {
+        std::cerr << "Could not make current context" << std::endl
+            << "Error: 0x" << std::hex << eglGetError() << std::endl;
+        return false;
+    };
+    return true;
+}
+
+void DestroyContext()
+{
+    // terminate egl at end
+    eglTerminate(context.m_display);
+};
+
 #else
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -685,6 +796,7 @@ void DestroyContext()
     };
 };
 #endif
+#endif
 
 bool initGPU(int *argcp, char **argv)
 {
