@@ -159,17 +159,7 @@ namespace detail
             {
                 exinfo1.setPosition(remapped.boundingBox().upperLeft());
                 exinfo1.setCanvasSize(vigra::Size2D(opts.getWidth(), opts.getHeight()));
-                vigra::Rect2D rect = remapped.boundingBox();
-                if (rect.right() > opts.getROI().right())
-                {
-                    rect &= opts.getROI();
-                    rect.moveBy(-rect.upperLeft());
-                    vigra::exportImage(srcImageRange(remapped.m_mask, rect), exinfo1);
-                }
-                else
-                {
-                    vigra::exportImage(srcImageRange(remapped.m_mask), exinfo1);
-                };
+                vigra::exportImage(srcImageRange(remapped.m_mask), exinfo1);
             }
 
             // calculate real alpha for saving with the image
@@ -177,7 +167,6 @@ namespace detail
             remapped.calcAlpha();
         }
 
-        vigra::Rect2D subImage;
         if (!opts.tiff_saveROI)
         {
             // FIXME: this is stupid. Should not require space for full image...
@@ -203,11 +192,6 @@ namespace detail
         {
             final_img = &remapped.m_image;
             alpha_img = &remapped.m_mask;
-            if (remapped.boundingBox().right() > opts.getROI().right())
-            {
-                subImage = remapped.boundingBox() & opts.getROI();
-                subImage.moveBy(-subImage.upperLeft());
-            };
         }
 
         std::string ext = opts.getOutputExtension();
@@ -230,7 +214,7 @@ namespace detail
             exinfo.setPosition(opts.getROI().upperLeft());
             exinfo.setCanvasSize(vigra::Size2D(opts.getWidth(), opts.getHeight()));
         }
-        if (opts.outputPixelType.size() > 0)
+        if (!opts.outputPixelType.empty())
         {
             exinfo.setPixelType(opts.outputPixelType.c_str());
         }
@@ -250,27 +234,13 @@ namespace detail
             };
         }
 
-        if (subImage.area() > 0)
+        if (supportsAlpha)
         {
-            if (supportsAlpha)
-            {
-                vigra::exportImageAlpha(srcImageRange(*final_img, subImage), srcImage(*alpha_img), exinfo);
-            }
-            else
-            {
-                vigra::exportImage(srcImageRange(*final_img, subImage), exinfo);
-            };
+            vigra::exportImageAlpha(srcImageRange(*final_img), srcImage(*alpha_img), exinfo);
         }
         else
         {
-            if (supportsAlpha)
-            {
-                vigra::exportImageAlpha(srcImageRange(*final_img), srcImage(*alpha_img), exinfo);
-            }
-            else
-            {
-                vigra::exportImage(srcImageRange(*final_img), exinfo);
-            };
+            vigra::exportImage(srcImageRange(*final_img), exinfo);
         };
     };
 } // namespace detail
@@ -321,6 +291,7 @@ public:
             if (GetAdvancedOption(advOptions, "ignoreExposure", false))
             {
                 modOptions.outputExposureValue = Base::m_pano.getImage(*it).getExposureValue();
+                modOptions.outputRangeCompression = 0.0;
             };
             RemappedPanoImage<ImageType, AlphaType> *
                 remapped = remapper.getRemapped(Base::m_pano, modOptions, *it, 
@@ -525,11 +496,12 @@ public:
             if (GetAdvancedOption(advOptions, "ignoreExposure", false))
             {
                 modOptions.outputExposureValue = Base::m_pano.getImage(*it).getExposureValue();
+                modOptions.outputRangeCompression = 0.0;
             };
             RemappedPanoImage<ImageType, AlphaType> *
                 remapped = remapper.getRemapped(Base::m_pano, modOptions, *it,
                     Base::m_rois[std::distance(imgSet.begin(), imgSet.find(*it))], Base::m_progress);
-            if(iccProfile.size()==0)
+            if(iccProfile.empty())
             {
                 iccProfile=remapped->m_ICCProfile;
             };
@@ -600,7 +572,7 @@ public:
         exinfo.setXResolution(150);
         exinfo.setYResolution(150);
         exinfo.setICCProfile(iccProfile);
-        if (opts.outputPixelType.size() > 0) {
+        if (!opts.outputPixelType.empty()) {
             exinfo.setPixelType(opts.outputPixelType.c_str());
         }
 
@@ -738,7 +710,7 @@ public:
 //        Base::m_progress.setMessage("saving result: " + hugin_utils::stripPath(outputfile));
         DEBUG_DEBUG("Saving panorama: " << outputfile);
         vigra::ImageExportInfo exinfo(outputfile.c_str(), GetAdvancedOption(advOptions, "useBigTIFF", false) ? "w8" : "w");
-        if (opts.outputPixelType.size() > 0) {
+        if (!opts.outputPixelType.empty()) {
             exinfo.setPixelType(opts.outputPixelType.c_str());
         }
         exinfo.setXResolution(150);
@@ -802,7 +774,7 @@ public:
             // but should be enought for the preview.
             remapped[i] = remapper.getRemapped(Base::m_pano, opts, *it,
                                                Base::m_rois[i], Base::m_progress);
-            if(iccProfile.size()==0)
+            if(iccProfile.empty())
             {
                 iccProfile=remapped[i]->m_ICCProfile;
             };
@@ -881,7 +853,7 @@ public:
             RemappedPanoImage<ImageType, AlphaType> *
             remapped = remapper.getRemapped(Base::m_pano, opts, *it,
                                             Base::m_rois[i], Base::m_progress);
-            if (iccProfile.size() == 0) {
+            if (iccProfile.empty()) {
                 // try to extract icc profile.
                 iccProfile = remapped->m_ICCProfile;
             }
