@@ -25,9 +25,6 @@
 
 #include "Stitcher.h"
 
-using namespace std;
-using namespace vigra;
-
 void HuginBase::Nona::stitchPanoGray_32_float(const PanoramaData & pano,
                                  const PanoramaOptions & opts,
                                  AppBase::ProgressDisplay* progress,
@@ -37,13 +34,13 @@ void HuginBase::Nona::stitchPanoGray_32_float(const PanoramaData & pano,
                                  const AdvancedOptions& advOptions)
 {
     if (strcmp(pixelType, "UINT32") == 0 ) {
-        stitchPanoIntern<UInt32Image, BImage>(pano, opts, progress, basename, usedImgs, advOptions);
+        stitchPanoIntern<vigra::UInt32Image, vigra::BImage>(pano, opts, progress, basename, usedImgs, advOptions);
     } else if (strcmp(pixelType, "INT32") == 0 ) {
-        stitchPanoIntern<IImage, BImage>(pano, opts, progress, basename, usedImgs, advOptions);
+        stitchPanoIntern<vigra::IImage, vigra::BImage>(pano, opts, progress, basename, usedImgs, advOptions);
     } else if (strcmp(pixelType, "FLOAT") == 0 ) {
-        stitchPanoIntern<FImage, BImage>(pano, opts, progress, basename, usedImgs, advOptions);
+        stitchPanoIntern<vigra::FImage, vigra::BImage>(pano, opts, progress, basename, usedImgs, advOptions);
     } else if (strcmp(pixelType, "DOUBLE") == 0 ) {
-        stitchPanoIntern<DImage, BImage>(pano, opts, progress, basename, usedImgs, advOptions);
+        stitchPanoIntern<vigra::DImage, vigra::BImage>(pano, opts, progress, basename, usedImgs, advOptions);
     } else {
         UTILS_THROW(std::runtime_error, "Unsupported pixel type: " << pixelType );
         return;
