@@ -306,26 +306,27 @@ void SOR(Image& target, const Image& gradient, const SeamMask& seams, const floa
     {
         // changes in current iteration
         double error = 0;
-        if (seams[0][0]>1)
+        // special treatment of first line
+        if (seams[0][0] > 1)
         {
             if (doWrap)
             {
-                const TargetPixelType delta = omega*((gradient[0][0] + target[0][1] + 2 * target[1][0] + target[0][width - 1]) / 4.0f - target[0][0]);
+                const TargetPixelType delta = omega * ((gradient[0][0] + target[0][1] + 2 * target[1][0] + target[0][width - 1]) / 4.0f - target[0][0]);
                 error += detail::GetRealValue(delta*delta);
                 target[0][0] += delta;
             }
             else
             {
-                const TargetPixelType delta = omega*((gradient[0][0] + 2 * target[0][1] + 2 * target[1][0]) / 4.0f - target[0][0]);
+                const TargetPixelType delta = omega * ((gradient[0][0] + 2 * target[0][1] + 2 * target[1][0]) / 4.0f - target[0][0]);
                 error += detail::GetRealValue(delta*delta);
                 target[0][0] += delta;
             };
         };
         for (int x = 1; x < width - 1; ++x)
         {
-            if (seams[0][x]>1)
+            if (seams[0][x] > 1)
             {
-                const TargetPixelType delta = omega*((gradient[0][x] + detail::GetBorderValues(x, 0, 1, 0, target, seams) + 2 * target[1][x]) / 4.0f - target[0][x]);
+                const TargetPixelType delta = omega * ((gradient[0][x] + detail::GetBorderValues(x, 0, 1, 0, target, seams) + 2 * target[1][x]) / 4.0f - target[0][x]);
                 error += detail::GetRealValue(delta*delta);
                 target[0][x] += delta;
             };
@@ -334,13 +335,13 @@ void SOR(Image& target, const Image& gradient, const SeamMask& seams, const floa
         {
             if (doWrap)
             {
-                const TargetPixelType delta = omega*((gradient[0][width - 1] + target[0][width - 2] + 2 * target[1][width - 1] + target[0][0]) / 4.0f - target[0][width - 1]);
+                const TargetPixelType delta = omega * ((gradient[0][width - 1] + target[0][width - 2] + 2 * target[1][width - 1] + target[0][0]) / 4.0f - target[0][width - 1]);
                 error += detail::GetRealValue(delta*delta);
                 target[0][width - 1] += delta;
             }
             else
             {
-                const TargetPixelType delta = omega*((gradient[0][width - 1] + 2 * target[0][width - 2] + 2 * target[1][width - 1]) / 4.0f - target[0][width - 1]);
+                const TargetPixelType delta = omega * ((gradient[0][width - 1] + 2 * target[0][width - 2] + 2 * target[1][width - 1]) / 4.0f - target[0][width - 1]);
                 error += detail::GetRealValue(delta*delta);
                 target[0][width - 1] += delta;
             };
@@ -352,14 +353,14 @@ void SOR(Image& target, const Image& gradient, const SeamMask& seams, const floa
             {
                 if (doWrap)
                 {
-                    const TargetPixelType delta = omega*((gradient[y][0] + detail::GetBorderValues(0, y, 0, 1, target, seams)
+                    const TargetPixelType delta = omega * ((gradient[y][0] + detail::GetBorderValues(0, y, 0, 1, target, seams)
                         + target[y][1] + target[y][width - 1]) / 4.0f - target[y][0]);
                     error += detail::GetRealValue(delta*delta);
                     target[y][0] += delta;
                 }
                 else
                 {
-                    const TargetPixelType delta = omega*((gradient[y][0] + detail::GetBorderValues(0, y, 0, 1, target, seams) + 2 * target[y][1]) / 4.0f - target[y][0]);
+                    const TargetPixelType delta = omega * ((gradient[y][0] + detail::GetBorderValues(0, y, 0, 1, target, seams) + 2 * target[y][1]) / 4.0f - target[y][0]);
                     error += detail::GetRealValue(delta*delta);
                     target[y][0] += delta;
                 };
@@ -373,14 +374,14 @@ void SOR(Image& target, const Image& gradient, const SeamMask& seams, const floa
                     {
                         // border pixel
                         const TargetPixelType sum = detail::GetBorderValues(x, y, 1, 0, target, seams) + detail::GetBorderValues(x, y, 0, 1, target, seams);
-                        const TargetPixelType delta = omega*((gradient[y][x] + sum) / 4.0f - target[y][x]);
+                        const TargetPixelType delta = omega * ((gradient[y][x] + sum) / 4.0f - target[y][x]);
                         error += detail::GetRealValue(delta*delta);
                         target[y][x] += delta;
                     }
                     else
                     {
                         const TargetPixelType sum = target[y + 1][x] + target[y][x + 1] + target[y - 1][x] + target[y][x - 1];
-                        const TargetPixelType delta = omega*((gradient[y][x] + sum) / 4.0f - target[y][x]);
+                        const TargetPixelType delta = omega * ((gradient[y][x] + sum) / 4.0f - target[y][x]);
                         error += detail::GetRealValue(delta*delta);
                         target[y][x] += delta;
                     };
@@ -390,13 +391,13 @@ void SOR(Image& target, const Image& gradient, const SeamMask& seams, const floa
             {
                 if (doWrap)
                 {
-                    const TargetPixelType delta = omega*((gradient[y][width - 1] + detail::GetBorderValues(width - 1, y, 0, 1, target, seams) + target[y][width - 2] + target[y][0]) / 4.0f - target[y][width - 1]);
+                    const TargetPixelType delta = omega * ((gradient[y][width - 1] + detail::GetBorderValues(width - 1, y, 0, 1, target, seams) + target[y][width - 2] + target[y][0]) / 4.0f - target[y][width - 1]);
                     error += detail::GetRealValue(delta*delta);
                     target[y][width - 1] += delta;
                 }
                 else
                 {
-                    const TargetPixelType delta = omega*((gradient[y][width - 1] + detail::GetBorderValues(width - 1, y, 0, 1, target, seams) + 2 * target[y][width - 2]) / 4.0f - target[y][width - 1]);
+                    const TargetPixelType delta = omega * ((gradient[y][width - 1] + detail::GetBorderValues(width - 1, y, 0, 1, target, seams) + 2 * target[y][width - 2]) / 4.0f - target[y][width - 1]);
                     error += detail::GetRealValue(delta*delta);
                     target[y][width - 1] += delta;
                 };
@@ -407,13 +408,13 @@ void SOR(Image& target, const Image& gradient, const SeamMask& seams, const floa
         {
             if (doWrap)
             {
-                const TargetPixelType delta = omega*((gradient[height - 1][0] + 2 * target[height - 2][0] + target[height - 1][1] + target[height - 1][width - 1]) / 4.0f - target[height - 1][0]);
+                const TargetPixelType delta = omega * ((gradient[height - 1][0] + 2 * target[height - 2][0] + target[height - 1][1] + target[height - 1][width - 1]) / 4.0f - target[height - 1][0]);
                 error += detail::GetRealValue(delta*delta);
                 target[height - 1][0] += delta;
             }
             else
             {
-                const TargetPixelType delta = omega*((gradient[height - 1][0] + 2 * target[height - 2][0] + 2 * target[height - 1][1]) / 4.0f - target[height - 1][0]);
+                const TargetPixelType delta = omega * ((gradient[height - 1][0] + 2 * target[height - 2][0] + 2 * target[height - 1][1]) / 4.0f - target[height - 1][0]);
                 error += detail::GetRealValue(delta*delta);
                 target[height - 1][0] += delta;
             };
@@ -422,7 +423,7 @@ void SOR(Image& target, const Image& gradient, const SeamMask& seams, const floa
         {
             if (seams[height - 1][x] > 1)
             {
-                const TargetPixelType delta = omega*((gradient[height - 1][x] + detail::GetBorderValues(x, height - 1, 1, 0, target, seams) + 2 * target[height - 2][x]) / 4.0f - target[height - 1][x]);
+                const TargetPixelType delta = omega * ((gradient[height - 1][x] + detail::GetBorderValues(x, height - 1, 1, 0, target, seams) + 2 * target[height - 2][x]) / 4.0f - target[height - 1][x]);
                 error += detail::GetRealValue(delta*delta);
                 target[height - 1][x] += delta;
             };
@@ -431,13 +432,13 @@ void SOR(Image& target, const Image& gradient, const SeamMask& seams, const floa
         {
             if (doWrap)
             {
-                const TargetPixelType delta = omega*((gradient[height - 1][width - 1] + 2 * target[height - 2][width - 1] + target[height - 1][width - 2] + target[height - 1][0]) / 4.0f - target[height - 1][width - 1]);
+                const TargetPixelType delta = omega * ((gradient[height - 1][width - 1] + 2 * target[height - 2][width - 1] + target[height - 1][width - 2] + target[height - 1][0]) / 4.0f - target[height - 1][width - 1]);
                 error += detail::GetRealValue(delta*delta);
                 target[height - 1][width - 1] += delta;
             }
             else
             {
-                const TargetPixelType delta = omega*((gradient[height - 1][width - 1] + 2 * target[height - 2][width - 1] + 2 * target[height - 1][width - 2]) / 4.0f - target[height - 1][width - 1]);
+                const TargetPixelType delta = omega * ((gradient[height - 1][width - 1] + 2 * target[height - 2][width - 1] + 2 * target[height - 1][width - 2]) / 4.0f - target[height - 1][width - 1]);
                 error += detail::GetRealValue(delta*delta);
                 target[height - 1][width - 1] += delta;
             };
@@ -869,9 +870,11 @@ void Multigrid(Image& out, const Image& gradient, const vigra::ImagePyramid<Seam
     detail::CalcResidualError(err, out, gradient, seamMaskPyramid[maskIndex], doWrap);    // Fehler berechnen
     detail::RestrictErrorToNextLevel(err, err2);
     Multigrid(out2, err2, seamMaskPyramid, minLen, errorThreshold, maxIter, doWrap);
-    // again W cycle
-    Multigrid(out2, err2, seamMaskPyramid, minLen, errorThreshold, maxIter, doWrap); 
-    vigra::resizeImageLinearInterpolation(srcImageRange(out2), destImageRange(err)); 
+    // when using a W cycle calculation another run of multigrid would follow
+    // Multigrid(out2, err2, seamMaskPyramid, minLen, errorThreshold, maxIter, doWrap); 
+    // this results in artefacts, maybe there is still a small error in other lines
+    // so trying to disable the W cycle and remain in a V cycle
+    vigra::resizeImageNoInterpolation(srcImageRange(out2), destImageRange(err)); 
     vigra::omp::combineTwoImagesIf(vigra::srcImageRange(out), vigra::srcImage(err),
         vigra::srcImage(seamMaskPyramid[maskIndex], MaskGreaterAccessor<typename SeamMask::PixelType>(2)),
         vigra::destImage(out),
