@@ -104,6 +104,11 @@ static void usage(const char* name)
          << "  --distortion Try to load distortion information from lens database" << std::endl
          << "  --use-given-order  Use the image order as given from command line" << std::endl
          << "                     (By default images will be sorted by exposure values.)" << std::endl
+         << "  --align-to-first   Align all images to the first one. By default" << std::endl
+         << "                     align_image_stack matches all image pairs" << std::endl
+         << "                     consecutive." << std::endl
+         << "                     This implies also the --use-given-order option" << std::endl
+         << "  --dont-remap-ref   Don't output the remapped reference image" << std::endl
          << "  --gpu     Use GPU for remapping" << std::endl
          << "  -h        Display help (this text)" << std::endl
          << std::endl;
@@ -475,6 +480,8 @@ struct Parameters
         gpu = false;
         loadDistortion = false;
         sortImagesByEv = true;
+        alignToFirst = false;
+        dontRemapRef = false;
     }
 
     double cpErrorThreshold;
@@ -497,6 +504,8 @@ struct Parameters
     bool gpu;
     bool loadDistortion;
     bool sortImagesByEv;
+    bool alignToFirst;
+    bool dontRemapRef;
     int pyrLevel;
     std::string alignedPrefix;
     std::string ptoFile;
@@ -689,11 +698,7 @@ int main2(std::vector<std::string> files, Parameters param)
                 pano.unlinkImageVariableRadialDistortionCenterShift(0);
             }
             // All images are in the same stack: Link the stack variable.
-            pano.linkImageVariableStack(imgNr, 0);
-            // exposure value is linked, reset to value found in EXIF
-            pano.unlinkImageVariableExposureValue(0);
-            srcImg.setExposureValue(srcImg.calcExifExposureValue());
-            pano.setSrcImage(i, srcImg);
+            pano.linkImageVariableStack(0, imgNr);
             images.push_back(i);
             // optimize yaw, roll, pitch
             std::set<std::string> vars;
@@ -769,8 +774,16 @@ int main2(std::vector<std::string> files, Parameters param)
         {
             if (g_verbose > 0)
             {
-                std::cout << "Creating control points between " << pano.getSrcImage(images[i-1]).getFilename().c_str() << " and " <<
-                     pano.getSrcImage(images[i]).getFilename().c_str() << std::endl;
+                if (param.alignToFirst)
+                {
+                    std::cout << "Creating control points between " << pano.getSrcImage(images[0]).getFilename().c_str() << " and " <<
+                        pano.getSrcImage(images[i]).getFilename().c_str() << std::endl;
+                }
+                else
+                {
+                    std::cout << "Creating control points between " << pano.getSrcImage(images[i - 1]).getFilename().c_str() << " and " <<
+                        pano.getSrcImage(images[i]).getFilename().c_str() << std::endl;
+                };
             }
 
             // load the actual image data of the next image
@@ -796,15 +809,24 @@ int main2(std::vector<std::string> files, Parameters param)
             // add control points.
             // work on smaller images
             // TODO: or use a fast interest point operator.
-            createCtrlPoints(pano, images[i-1], *leftImg, *leftImgOrig, images[i], *rightImg, *rightImgOrig, param.pyrLevel, 2, param.nPoints, param.grid, param.corrThresh, param.stereo);
+            if (param.alignToFirst)
+            {
+                createCtrlPoints(pano, 0, *leftImg, *leftImgOrig, images[i], *rightImg, *rightImgOrig, param.pyrLevel, 2, param.nPoints, param.grid, param.corrThresh, param.stereo);
+                vigra::initImage(vigra::destImageRange(*rightImg), vigra::NumericTraits<PixelType>::zero());
+                vigra::initImage(vigra::destImageRange(*rightImgOrig), vigra::NumericTraits<PixelType>::zero());
+            }
+            else
+            {
+                createCtrlPoints(pano, images[i - 1], *leftImg, *leftImgOrig, images[i], *rightImg, *rightImgOrig, param.pyrLevel, 2, param.nPoints, param.grid, param.corrThresh, param.stereo);
 
-            // swap images;
-            delete leftImg;
-            delete leftImgOrig;
-            leftImg = rightImg;
-            leftImgOrig = rightImgOrig;
-            rightImg = new ImageType(leftImg->size());
-            rightImgOrig = new ImageType(leftImgOrig->size());
+                // swap images;
+                delete leftImg;
+                delete leftImgOrig;
+                leftImg = rightImg;
+                leftImgOrig = rightImgOrig;
+                rightImg = new ImageType(leftImg->size());
+                rightImgOrig = new ImageType(leftImgOrig->size());
+            };
         }
         delete leftImg;
         delete rightImg;
@@ -844,6 +866,21 @@ int main2(std::vector<std::string> files, Parameters param)
             {
                 alignStereoWindow(pano, param.pop_out);
             }
+            if (param.optHFOV)
+            {
+                // check that reference image contains cp, otherwise optimizing hfov
+                // goes haywire
+                if (pano.getCtrlPointsForImage(0).empty())
+                {
+                    std::cerr << std::endl << "After control points pruning reference images has no control" << std::endl
+                        << "points Optimizing field of view in this case results in undefined" << std::endl
+                        << "behaviour. Increase error distance (-t parameter), tweak cp" << std::endl
+                        << "detection parameters or don't optimize HFOV." << std::endl
+                        << std::endl
+                        << "Exiting..." << std::endl;
+                    return 1;
+                };
+            };
             // reoptimize
             optimizeError = (HuginBase::PTools::optimize(pano) > 0);
         }
@@ -852,11 +889,16 @@ int main2(std::vector<std::string> files, Parameters param)
         {
             autoCrop(pano);
         }
+        // deactivate ref image if requested
+        if (param.dontRemapRef)
+        {
+            pano.activateImage(0, false);
+        };
 
         HuginBase::UIntSet imgs = pano.getActiveImages();
         if (optimizeError)
         {
-            if (param.ptoFile.size() > 0)
+            if (!param.ptoFile.empty())
             {
                 std::ofstream script(param.ptoFile.c_str());
                 pano.printPanoramaScript(script, optvars, pano.getOptions(), imgs, false, "");
@@ -879,7 +921,6 @@ int main2(std::vector<std::string> files, Parameters param)
             opts.outputFormat = HuginBase::PanoramaOptions::HDR;
             opts.outputPixelType = "FLOAT";
             opts.outputMode = HuginBase::PanoramaOptions::OUTPUT_HDR;
-            opts.outfile = param.hdrFile;
             pano.setOptions(opts);
 
             // remap all images
@@ -893,8 +934,8 @@ int main2(std::vector<std::string> files, Parameters param)
                 progress = new AppBase::DummyProgressDisplay();
             };
             HuginBase::Nona::stitchPanorama(pano, pano.getOptions(),
-                           progress, opts.outfile, imgs);
-            std::cout << "Written HDR output to " << opts.outfile << std::endl;
+                           progress, param.hdrFile, imgs);
+            std::cout << "Written HDR output to " << param.hdrFile << std::endl;
             delete progress;
         }
         if (param.alignedPrefix.size())
@@ -904,7 +945,6 @@ int main2(std::vector<std::string> files, Parameters param)
             opts.outputMode = HuginBase::PanoramaOptions::OUTPUT_LDR;
             opts.outputFormat = HuginBase::PanoramaOptions::TIFF_m;
             opts.outputPixelType = "";
-            opts.outfile = param.alignedPrefix;
             opts.remapUsingGPU = param.gpu;
             pano.setOptions(opts);
             // remap all images
@@ -921,13 +961,13 @@ int main2(std::vector<std::string> files, Parameters param)
             HuginBase::Nona::AdvancedOptions advOpts;
             HuginBase::Nona::SetAdvancedOption(advOpts, "ignoreExposure", true);
             HuginBase::Nona::stitchPanorama(pano, pano.getOptions(),
-                           progress, opts.outfile, imgs, advOpts);
+                           progress, param.alignedPrefix, imgs, advOpts);
             delete progress;
-            std::cout << "Written aligned images to files with prefix \"" << opts.outfile << "\"" << std::endl;
+            std::cout << "Written aligned images to files with prefix \"" << param.alignedPrefix << "\"" << std::endl;
         }
 
         // At this point we have panorama options set according to the output
-        if (param.ptoFile.size() > 0)
+        if (!param.ptoFile.empty())
         {
             std::ofstream script(param.ptoFile.c_str());
             pano.printPanoramaScript(script, optvars, pano.getOptions(), imgs, false, "");
@@ -960,15 +1000,20 @@ int main(int argc, char* argv[])
         GPU,
         LENSDB,
         USEGIVENORDER,
+        ALIGNTOFIRST,
+        DONTREMAPREF,
     };
 
     static struct option longOptions[] =
     {
         {"corr", required_argument, NULL, CORRTHRESH },
+        {"verbose", no_argument, NULL, 'v'},
         {"threads", required_argument, NULL, THREADS },
         {"gpu", no_argument, NULL, GPU },
         {"distortion", no_argument, NULL, LENSDB },
         {"use-given-order", no_argument, NULL, USEGIVENORDER },
+        {"align-to-first", no_argument, NULL, ALIGNTOFIRST},
+        {"dont-remap-ref", no_argument, NULL, DONTREMAPREF},
         {"help", no_argument, NULL, 'h' },
         0
     };
@@ -1090,6 +1135,13 @@ int main(int argc, char* argv[])
             case USEGIVENORDER:
                 param.sortImagesByEv = false;
                 break;
+            case ALIGNTOFIRST:
+                param.alignToFirst = true;
+                param.sortImagesByEv = false;
+                break;
+            case DONTREMAPREF:
+                param.dontRemapRef = true;
+                break;
             case ':':
             case '?':
                 // missing argument or invalid switch
