@@ -35,6 +35,7 @@
 #include <vigra/functorexpression.hxx>
 #include <vigra_ext/utils.h>
 #include <hugin_utils/openmp_lock.h>
+#include <algorithms/optimizer/PTOptimizer.h>
 
 extern "C"
 {
@@ -124,15 +125,14 @@ void convertGrayToUInt8(SrcIMG& src, const std::string& origType, vigra::BImage&
 }
 
 template <class SrcIMG>
-vigra::BImage LoadGrayImageAndConvert(vigra::ImageImportInfo& info)
+vigra::BImage LoadGrayImageAndConvert(vigra::ImageImportInfo& info, vigra::BImage& mask)
 {
     vigra::BImage image;
     SrcIMG imageIn(info.width(),info.height());
     if(info.numExtraBands()==1)
     {
-        vigra::BImage mask(info.size());
+        mask.resize(info.width(), info.height());
         vigra::importImageAlpha(info,destImage(imageIn),destImage(mask));
-        mask.resize(0,0);
     }
     else
     {
@@ -144,15 +144,14 @@ vigra::BImage LoadGrayImageAndConvert(vigra::ImageImportInfo& info)
 };
 
 template <class SrcIMG>
-vigra::UInt8RGBImage LoadImageAndConvert(vigra::ImageImportInfo& info)
+vigra::UInt8RGBImage LoadImageAndConvert(vigra::ImageImportInfo& info, vigra::BImage& mask)
 {
     vigra::UInt8RGBImage image;
     SrcIMG imageIn(info.width(),info.height());
     if(info.numExtraBands()==1)
     {
-        vigra::BImage mask(info.size());
+        mask.resize(info.width(), info.height());
         vigra::importImageAlpha(info,destImage(imageIn),destImage(mask));
-        mask.resize(0,0);
     }
     else
     {
@@ -167,6 +166,7 @@ vigra::UInt8RGBImage LoadImageAndConvert(vigra::ImageImportInfo& info)
 HuginBase::CPVector LoadGrayImageAndFindLines(vigra::ImageImportInfo info, HuginBase::Panorama& pano, size_t imgNr, int nrLines)
 {
     vigra::BImage image;
+    vigra::BImage mask;
     HuginBase::CPVector lineCp;
     std::string pixelType=info.getPixelType();
     if(pixelType=="UINT8")
@@ -174,9 +174,8 @@ HuginBase::CPVector LoadGrayImageAndFindLines(vigra::ImageImportInfo info, Hugin
         image.resize(info.width(),info.height());
         if(info.numExtraBands()==1)
         {
-            vigra::BImage mask(info.size());
+            mask.resize(info.width(), info.height());
             vigra::importImageAlpha(info,destImage(image),destImage(mask));
-            mask.resize(0,0);
         }
         else
         {
@@ -187,19 +186,19 @@ HuginBase::CPVector LoadGrayImageAndFindLines(vigra::ImageImportInfo info, Hugin
     {
         if(pixelType=="UINT16" || pixelType=="INT16")
         {
-            image=LoadGrayImageAndConvert<vigra::UInt16Image>(info);
+            image=LoadGrayImageAndConvert<vigra::UInt16Image>(info, mask);
         }
         else
         {
             if(pixelType=="INT32" || pixelType=="UINT32")
             {
-                image=LoadGrayImageAndConvert<vigra::UInt32Image>(info);
+                image=LoadGrayImageAndConvert<vigra::UInt32Image>(info, mask);
             }
             else
             {
                 if(pixelType=="FLOAT" || pixelType=="DOUBLE")
                 {
-                    image=LoadGrayImageAndConvert<vigra::FImage>(info);
+                    image=LoadGrayImageAndConvert<vigra::FImage>(info, mask);
                 }
                 else
                 {
@@ -210,7 +209,7 @@ HuginBase::CPVector LoadGrayImageAndFindLines(vigra::ImageImportInfo info, Hugin
     };
     if(image.width()>0 && image.height()>0)
     {
-        lineCp=HuginLines::GetVerticalLines(pano, imgNr, image, nrLines);
+        lineCp=HuginLines::GetVerticalLines(pano, imgNr, image, mask, nrLines);
     };
     return lineCp;
 };
@@ -219,6 +218,7 @@ HuginBase::CPVector LoadGrayImageAndFindLines(vigra::ImageImportInfo info, Hugin
 HuginBase::CPVector LoadImageAndFindLines(vigra::ImageImportInfo info, HuginBase::Panorama& pano, size_t imgNr, int nrLines)
 {
     vigra::UInt8RGBImage image;
+    vigra::BImage mask;
     HuginBase::CPVector lineCp;
     std::string pixelType=info.getPixelType();
     if(pixelType=="UINT8")
@@ -226,9 +226,8 @@ HuginBase::CPVector LoadImageAndFindLines(vigra::ImageImportInfo info, HuginBase
         image.resize(info.width(),info.height());
         if(info.numExtraBands()==1)
         {
-            vigra::BImage mask(info.size());
+            mask.resize(info.width(), info.height());
             vigra::importImageAlpha(info,destImage(image),destImage(mask));
-            mask.resize(0,0);
         }
         else
         {
@@ -239,19 +238,19 @@ HuginBase::CPVector LoadImageAndFindLines(vigra::ImageImportInfo info, HuginBase
     {
         if(pixelType=="UINT16" || pixelType=="INT16")
         {
-            image=LoadImageAndConvert<vigra::UInt16RGBImage>(info);
+            image=LoadImageAndConvert<vigra::UInt16RGBImage>(info, mask);
         }
         else
         {
             if(pixelType=="INT32" || pixelType=="UINT32")
             {
-                image=LoadImageAndConvert<vigra::UInt32RGBImage>(info);
+                image=LoadImageAndConvert<vigra::UInt32RGBImage>(info, mask);
             }
             else
             {
                 if(pixelType=="FLOAT" || pixelType=="DOUBLE")
                 {
-                    image=LoadImageAndConvert<vigra::FRGBImage>(info);
+                    image=LoadImageAndConvert<vigra::FRGBImage>(info, mask);
                 }
                 else
                 {
@@ -262,7 +261,7 @@ HuginBase::CPVector LoadImageAndFindLines(vigra::ImageImportInfo info, HuginBase
     };
     if(image.width()>0 && image.height()>0)
     {
-        lineCp=HuginLines::GetVerticalLines(pano, imgNr, image, nrLines);
+        lineCp=HuginLines::GetVerticalLines(pano, imgNr, image, mask, nrLines);
     }
     return lineCp;
 };
@@ -370,12 +369,9 @@ int main(int argc, char* argv[])
         return 1;
     }
 
-    if(pano.getNrOfImages()==0)
-    {
-        std::cerr << "error: project file does not contains any image" << std::endl;
-        std::cerr << "aborting processing" << std::endl;
-        return 1;
-    };
+    // disable progress messages from libpano optimizer
+    PT_setProgressFcn(ptProgress);
+    PT_setInfoDlgFcn(ptinfoDlg);
 
     std::vector<size_t> imagesToProcess;
     if(cmdlineImages.empty())
@@ -404,6 +400,36 @@ int main(int argc, char* argv[])
                 std::copy(stackImages.begin(), stackImages.end(), std::back_inserter(imagesToProcess));
             };
         };
+        if (pano.getNrOfCtrlPoints())
+        {
+            // pano has already control points, so do a pair-wise optimisation to get
+            // rough positions of the images, so we can decide which images are near
+            // the zenit/nadir and ignore these images
+            HuginBase::Panorama optPano = pano.duplicate();
+            // reset translation parameters
+            HuginBase::VariableMapVector varMapVec = optPano.getVariables();
+            for (size_t i = 0; i < varMapVec.size(); i++)
+            {
+                map_get(varMapVec[i], "TrX").setValue(0);
+                map_get(varMapVec[i], "TrY").setValue(0);
+                map_get(varMapVec[i], "TrZ").setValue(0);
+            };
+            optPano.updateVariables(varMapVec);
+            // now do a pairwise optimisation
+            HuginBase::AutoOptimise(optPano).run();
+            std::vector<size_t> imagesToCheck;
+            std::swap(imagesToProcess, imagesToCheck);
+            for (auto& img:imagesToCheck)
+            {
+                // now remove all images from list where pitch > 50 or < -50 -> images near zenit/nadir
+                if (std::abs(optPano.getImage(img).getPitch()) < 50)
+                {
+                    imagesToProcess.push_back(img);
+                    std::cout << "line";
+                };
+                std::cout << std::endl;
+            };
+        }
     }
     else
     {
@@ -423,9 +449,6 @@ int main(int argc, char* argv[])
         return 1;
     };
 
-    PT_setProgressFcn(ptProgress);
-    PT_setInfoDlgFcn(ptinfoDlg);
-
     std::cout << hugin_utils::stripPath(argv[0]) << " is searching for vertical lines" << std::endl;
 #if _WIN32
     //multi threading of image loading results sometime in a race condition
@@ -434,11 +457,11 @@ int main(int argc, char* argv[])
     std::string s=vigra::impexListExtensions();
 #endif
 
-    size_t nrCPS=pano.getNrOfCtrlPoints();
-    #pragma omp parallel for schedule(dynamic)
+    const size_t nrCPS=pano.getNrOfCtrlPoints();
+#pragma omp parallel for schedule(dynamic)
     for(int i=0; i < imagesToProcess.size(); ++i)
     {
-        unsigned int imgNr=imagesToProcess[i];
+        const size_t imgNr = imagesToProcess[i];
         std::ostringstream buf;
         buf << "Working on image " << pano.getImage(imgNr).getFilename() << std::endl;
         std::cout << buf.str();
