@@ -52,6 +52,9 @@ static void usage(const char* name)
          << "  Options:" << std::endl
          << "    -o, --output=file.pto  Output Hugin PTO file. Default: <filename>_mod.pto" << std::endl
          << "    -p, --projection=x     Sets the output projection to number x" << std::endl
+         << "    --projection-parameter=x    Sets the parameter of the projection" << std::endl
+         << "                                (Several parameters are separated by"<<std::endl
+         << "                                space or comma)" << std::endl
          << "    --fov=AUTO|HFOV|HFOVxVFOV   Sets field of view" << std::endl
          << "                                AUTO: calculates optimal fov" << std::endl
          << "                                HFOV|HFOVxVFOV: set to given fov" << std::endl
@@ -67,6 +70,9 @@ static void usage(const char* name)
          << "                                left,right,top,bottom: to given size" << std::endl
          << "    --output-exposure=AUTO|num  Sets the output exposure value to mean" << std::endl
          << "                                exposure (AUTO) or to given value" << std::endl
+         << "                                Prefix number with r for relativ change" << std::endl
+         << "    --output-range-compression=num  Set range compression" << std::endl
+         << "                                    Value should be a real in range 0..20" << std::endl
          << "    --output-cropped-tiff    Output cropped tiffs as intermediate images" << std::endl
          << "    --output-uncropped-tiff  Output uncropped tiffs as intermediate images" << std::endl
          << "    --output-type=str       Sets the type of output" << std::endl
@@ -94,8 +100,12 @@ static void usage(const char* name)
          << "                              For TIF: NONE|PACKBITS|LZW|DEFLATE" << std::endl
          << "    --blender=ENBLEND|INTERNAL  Sets the blender to be used at stitching" << std::endl
          << "                            stage." << std::endl
+         << "    --blender-args=str      Sets the arguments for the blender" << std::endl
+         << "    --fusion-args=str       Sets the arguments for the fusion program" << std::endl
+         << "    --hdrmerge-args=str     Setst the arguments for hdrmerge" << std::endl
          << "    --rotate=yaw,pitch,roll Rotates the whole panorama with the given angles" << std::endl
          << "    --translate=x,y,z       Translate the whole panorama with the given values" << std::endl
+         << "    --interpolation=int     Sets the interpolation method" << std::endl
          << "    -h, --help             Shows this help" << std::endl
          << std::endl;
 }
@@ -113,6 +123,7 @@ int main(int argc, char* argv[])
         SWITCH_ROTATE,
         SWITCH_TRANSLATE,
         SWITCH_EXPOSURE,
+        SWITCH_RANGE_COMPRESSION,
         SWITCH_OUTPUT_TYPE,
         SWITCH_BLENDER,
         SWITCH_LDRFILETYPE,
@@ -120,12 +131,18 @@ int main(int argc, char* argv[])
         SWITCH_HDRFILETYPE,
         SWITCH_HDRCOMPRESSION,
         SWITCH_CROPPED_TIFF,
-        SWITCH_UNCROPPED_TIFF
+        SWITCH_UNCROPPED_TIFF,
+        SWITCH_BLENDER_ARGS,
+        SWITCH_FUSION_ARGS,
+        SWITCH_HDRMERGE_ARGS,
+        SWITCH_PROJECTION_PARAMETER,
+        SWITCH_INTERPOLATION
     };
     static struct option longOptions[] =
     {
         {"output", required_argument, NULL, 'o' },
         {"projection", required_argument, NULL, 'p' },
+        {"projection-parameter", required_argument, NULL, SWITCH_PROJECTION_PARAMETER },
         {"fov", required_argument, NULL, SWITCH_FOV },
         {"straighten", no_argument, NULL, 's' },
         {"center", no_argument, NULL, 'c' },
@@ -134,19 +151,25 @@ int main(int argc, char* argv[])
         {"output-cropped-tiff", no_argument, NULL, SWITCH_CROPPED_TIFF },
         {"output-uncropped-tiff", no_argument, NULL, SWITCH_UNCROPPED_TIFF },
         {"output-exposure", required_argument, NULL, SWITCH_EXPOSURE },
+        {"output-range-compression", required_argument, NULL, SWITCH_RANGE_COMPRESSION },
         {"output-type", required_argument, NULL, SWITCH_OUTPUT_TYPE },
         {"blender", required_argument, NULL, SWITCH_BLENDER },
+        {"blender-args", required_argument, NULL, SWITCH_BLENDER_ARGS },
+        {"fusion-args", required_argument, NULL, SWITCH_FUSION_ARGS },
+        {"hdrmerge-args", required_argument, NULL, SWITCH_HDRMERGE_ARGS },
         {"ldr-file", required_argument,NULL, SWITCH_LDRFILETYPE },
         {"ldr-compression", required_argument, NULL, SWITCH_LDRCOMPRESSION },
         {"hdr-file", required_argument, NULL, SWITCH_HDRFILETYPE },
         {"hdr-compression", required_argument, NULL, SWITCH_HDRCOMPRESSION },
         {"rotate", required_argument, NULL, SWITCH_ROTATE },
         {"translate", required_argument, NULL, SWITCH_TRANSLATE },
+        {"interpolation", required_argument, NULL, SWITCH_INTERPOLATION},
         {"help", no_argument, NULL, 'h' },
         0
     };
 
     int projection=-1;
+    std::vector<double> projParameter;
     double newHFOV=-1;
     double newVFOV=-1;
     int scale=100;
@@ -168,6 +191,8 @@ int main(int argc, char* argv[])
     double y = 0;
     double z = 0;
     double outputExposure = -1000;
+    double outputRangeCompression = -1;
+    bool relativeExposure = false;
     bool calcMeanExposure = false;
     std::string outputType;
     std::string ldrfiletype;
@@ -177,6 +202,11 @@ int main(int argc, char* argv[])
     std::string output;
     std::string param;
     std::string blender;
+#define EMPTYARG "(empty)"
+    std::string blenderArgs(EMPTYARG);
+    std::string fusionArgs(EMPTYARG);
+    std::string hdrMergeArgs(EMPTYARG);
+    int interpolation = -1;
     while ((c = getopt_long (argc, argv, optstring, longOptions,nullptr)) != -1)
     {
         switch (c)
@@ -201,6 +231,26 @@ int main(int argc, char* argv[])
                     return 1;
                 };
                 break;
+            case SWITCH_PROJECTION_PARAMETER:
+                // projection parameters
+                {
+                    // split at space or comma
+                    std::vector<std::string> parameter = hugin_utils::SplitString(optarg, ", ");
+                    for(const auto& p: parameter)
+                    { 
+                        double d;
+                        if (hugin_utils::stringToDouble(p, d))
+                        {
+                            projParameter.push_back(d);
+                        }
+                        else
+                        { 
+                            std::cerr << hugin_utils::stripPath(argv[0]) << ": Could not parse projection parameters \"" << optarg << "\"." << std::endl;
+                            return 1;
+                        };
+                    };
+                }
+                break;
             case SWITCH_FOV:
                 //field of view
                 param=optarg;
@@ -352,14 +402,40 @@ int main(int argc, char* argv[])
                 }
                 else
                 {
-                    int n = sscanf(optarg, "%lf", &outputExposure);
-                    if (n != 1)
+                    if (!param.empty())
+                    {
+                        // if first character is r assume relative exposure values
+                        relativeExposure = (param[0] == 'R');
+                        if (relativeExposure)
+                        {
+                            param.erase(0, 1);
+                        };
+                        int n = sscanf(param.c_str(), "%lf", &outputExposure);
+                        if (n != 1)
+                        {
+                            std::cerr << hugin_utils::stripPath(argv[0]) << ": Could not parse output exposure value." << std::endl;
+                            return 1;
+                        };
+                    }
+                    else
                     {
                         std::cerr << hugin_utils::stripPath(argv[0]) << ": Could not parse output exposure value." << std::endl;
                         return 1;
                     };
                 };
                 break;
+            case SWITCH_RANGE_COMPRESSION:
+                if(!hugin_utils::stringToDouble(std::string(optarg), outputRangeCompression))
+                { 
+                    std::cerr << hugin_utils::stripPath(argv[0]) << ": Could not parse output range compression (" << optarg << ")." << std::endl;
+                    return 1;
+                };
+                if (outputRangeCompression < 0.0 || outputRangeCompression > 20.0)
+                {
+                    std::cerr << hugin_utils::stripPath(argv[0]) << ": range compression must be a real between 0 and 20." << std::endl;
+                    return 1;
+                };
+                break;
             case SWITCH_OUTPUT_TYPE:
                 if (!outputType.empty())
                 {
@@ -382,6 +458,15 @@ int main(int argc, char* argv[])
             case SWITCH_HDRCOMPRESSION:
                 hdrcompression = hugin_utils::toupper(hugin_utils::StrTrim(optarg));
                 break;
+            case SWITCH_BLENDER_ARGS:
+                blenderArgs = optarg;
+                break;
+            case SWITCH_FUSION_ARGS:
+                fusionArgs = optarg;
+                break;
+            case SWITCH_HDRMERGE_ARGS:
+                hdrMergeArgs = optarg;
+                break;
             case SWITCH_ROTATE:
                 {
                     int n=sscanf(optarg, "%lf,%lf,%lf", &yaw, &pitch, &roll);
@@ -402,6 +487,18 @@ int main(int argc, char* argv[])
                     };
                 };
                 break;
+            case SWITCH_INTERPOLATION:
+                if (!hugin_utils::stringToInt(optarg, interpolation))
+                {
+                    std::cerr << hugin_utils::stripPath(argv[0]) << ": Could not parse interpolation value. Given: \"" << optarg << "\"" << std::endl;
+                    return 1;
+                };
+                if (interpolation<0 || interpolation>vigra_ext::INTERP_SINC_1024)
+                {
+                    std::cerr << hugin_utils::stripPath(argv[0]) << ": Interpolator " << interpolation << " is not valid." << std::endl;
+                    return 1;
+                }
+                break;
             case ':':
             case '?':
                 // missing argument or invalid switch
@@ -468,6 +565,42 @@ int main(int argc, char* argv[])
         }
         pano.setOptions(opt);
     };
+    // set projection parameters
+    if (!projParameter.empty())
+    {
+        HuginBase::PanoramaOptions opt = pano.getOptions();
+        if (projParameter.size() > opt.m_projFeatures.numberOfParameters)
+        {
+            std::cout << "Warning: Given " << projParameter.size() << " projection parameters, but projection supports" << std::endl
+                << "         only " << opt.m_projFeatures.numberOfParameters << ". Ignoring surplus parameters." << std::endl;
+            while (projParameter.size() > opt.m_projFeatures.numberOfParameters)
+            {
+                projParameter.pop_back();
+            }
+        }
+        if (!projParameter.empty())
+        {
+            std::vector<double> newProjParameters = opt.getProjectionParameters();
+            std::copy(projParameter.begin(), projParameter.end(), newProjParameters.begin());
+            opt.setProjectionParameters(newProjParameters);
+            // read back, new the limits have been applied
+            newProjParameters = opt.getProjectionParameters();
+            auto it = newProjParameters.begin();
+            std::cout << "Setting projection parameters to: " << *it;
+            ++it;
+            while (it != newProjParameters.end())
+            {
+                std::cout << ", " << *it;
+                ++it;
+            }
+            std::cout << std::endl;
+            pano.setOptions(opt);
+        }
+        else
+        {
+            std::cout << "Warning: Current projection does not support projection parameters." << std::endl;
+        }
+    }
     // output exposure value
     if (outputExposure > -1000 || calcMeanExposure)
     {
@@ -478,11 +611,26 @@ int main(int argc, char* argv[])
         }
         else
         {
-            opt.outputExposureValue = outputExposure;
+            if (relativeExposure)
+            {
+                opt.outputExposureValue += outputExposure;
+            }
+            else
+            {
+                opt.outputExposureValue = outputExposure;
+            };
         };
         std::cout << "Setting output exposure value to " << opt.outputExposureValue << std::endl;
         pano.setOptions(opt);
     };
+    // output range compression
+    if (outputRangeCompression >= 0.0)
+    {
+        HuginBase::PanoramaOptions opt = pano.getOptions();
+        opt.outputRangeCompression = outputRangeCompression;
+        std::cout << "Setting output range compression to " << opt.outputRangeCompression << std::endl;
+        pano.setOptions(opt);
+    };
     // output type: normal, fused, hdr pano..
     if (!outputType.empty())
     {
@@ -625,6 +773,39 @@ int main(int argc, char* argv[])
         };
         pano.setOptions(opt);
     }
+    if (blenderArgs != EMPTYARG)
+    {
+        HuginBase::PanoramaOptions opt = pano.getOptions();
+        switch (opt.blendMode)
+        {
+            case HuginBase::PanoramaOptions::ENBLEND_BLEND:
+                opt.enblendOptions = blenderArgs;
+                std::cout << "Setting enblend arguments to " << blenderArgs << std::endl;
+                break;
+            case HuginBase::PanoramaOptions::INTERNAL_BLEND:
+                opt.verdandiOptions = blenderArgs;
+                std::cout << "Setting verdandi arguments to " << blenderArgs << std::endl;
+                break;
+            default:
+                std::cout << "Unknown blender in pto file." << std::endl;
+                break;
+        };
+        pano.setOptions(opt);
+    };
+    if (fusionArgs != EMPTYARG)
+    {
+        HuginBase::PanoramaOptions opt = pano.getOptions();
+        opt.enfuseOptions = fusionArgs;
+        std::cout << "Setting enfuse arguments to " << fusionArgs << std::endl;
+        pano.setOptions(opt);
+    };
+    if (hdrMergeArgs != EMPTYARG)
+    {
+        HuginBase::PanoramaOptions opt = pano.getOptions();
+        opt.hdrmergeOptions = hdrMergeArgs;
+        std::cout << "Setting hugin_hdrdmerge arguments to " << hdrMergeArgs << std::endl;
+        pano.setOptions(opt);
+    };
     // ldr output file type
     if (!ldrfiletype.empty())
     {
@@ -848,6 +1029,14 @@ int main(int argc, char* argv[])
         std::cout << "Set crop size to " << newROI.left() << "," << newROI.right() << "," << newROI.top() << "," << newROI.bottom() << std::endl;
         pano.setOptions(opt);
     };
+    //setting interpolation method
+    if (interpolation>=0)
+    {
+        HuginBase::PanoramaOptions opt = pano.getOptions();
+        opt.interpolator = static_cast<vigra_ext::Interpolator>(interpolation);
+        std::cout << "Set interpolation method to " << interpolation << std::endl;
+        pano.setOptions(opt);
+    };
 
     //write output
     HuginBase::OptimizeVector optvec = pano.getOptimizeVector();
