@@ -234,15 +234,8 @@ int main(int argc, char* argv[])
         return 1;
     }
 
-    if(pano.getNrOfImages()==0)
-    {
-        std::cerr << "error: project file does not contains any image" << std::endl;
-        std::cerr << "aborting processing" << std::endl;
-        return 1;
-    };
-
     // new lenses
-    if(newLensImgs.size()>0)
+    if(!newLensImgs.empty())
     {
         HuginBase::StandardImageVariableGroups variable_groups(pano);
         if(variable_groups.getLenses().getNumberOfParts()<pano.getNrOfImages())
@@ -265,7 +258,7 @@ int main(int argc, char* argv[])
     };
 
     // new stacks
-    if(newStackImgs.size()>0)
+    if(!newStackImgs.empty())
     {
         HuginBase::StandardImageVariableGroups variable_groups(pano);
         if(variable_groups.getStacks().getNumberOfParts()<pano.getNrOfImages())
@@ -288,7 +281,7 @@ int main(int argc, char* argv[])
     };
 
     // change lenses
-    if(changeLensImgs.size()>0)
+    if(!changeLensImgs.empty())
     {
         HuginBase::StandardImageVariableGroups variable_groups(pano);
         size_t lensCount=variable_groups.getLenses().getNumberOfParts();
@@ -312,12 +305,12 @@ int main(int argc, char* argv[])
         else
         {
             std::cout << "Warning: Pto project contains only one lens." << std::endl
-                 << "         Therefor the lens can not be changed. Use --new-lens instead." << std::endl;
+                 << "         Therefore the lens can not be changed. Use --new-lens instead." << std::endl;
         };
     };
 
     // change stacks
-    if(changeStackImgs.size()>0)
+    if(!changeStackImgs.empty())
     {
         HuginBase::StandardImageVariableGroups variable_groups(pano);
         size_t stackCount=variable_groups.getStacks().getNumberOfParts();
