@@ -160,7 +160,7 @@ static void usage(const char* name)
         << "                              Only pixel which differ more than" << std::endl
         << "                              mask-sigma * standard deviation" << std::endl
         << "                              are visible in output" << std::endl
-        << "                              available for modes median|winsor|clip" << std::endl
+        << "                              available for modes median, winsor or sigma" << std::endl
         << "     --mask-suffix=STRING     Suffix for the masked input images" << std::endl
         << "                              (default: _mask)" << std::endl
         << "     --mask-sigma=NUMBER      Sigma parameter for input images masking" << std::endl
@@ -1254,6 +1254,18 @@ int main(int argc, char* argv[])
         {
             success = main_stacker<vigra::RGBValue<vigra::UInt16>>(images);
         }
+        else if (pixeltype == "UINT32")
+        {
+            success = main_stacker<vigra::RGBValue<vigra::UInt32>>(images);
+        }
+        else if (pixeltype == "FLOAT")
+        {
+            success = main_stacker<vigra::RGBValue<float>>(images);
+        }
+        else if (pixeltype == "DOUBLE")
+        {
+            success = main_stacker<vigra::RGBValue<double>>(images);
+        }
         else
         {
             std::cerr << " ERROR: unsupported pixel type: " << pixeltype << std::endl;
@@ -1270,6 +1282,18 @@ int main(int argc, char* argv[])
         {
             success = main_stacker<vigra::UInt16>(images);
         }
+        else if (pixeltype == "UINT32")
+        {
+            success = main_stacker<vigra::UInt32>(images);
+        }
+        else if (pixeltype == "FLOAT")
+        {
+            success = main_stacker<float>(images);
+        }
+        else if (pixeltype == "DOUBLE")
+        {
+            success = main_stacker<double>(images);
+        }
         else
         {
             std::cerr << " ERROR: unsupported pixel type: " << pixeltype << std::endl;
